@@ -146,5 +146,8 @@ gb_init(GB * G) {
 	G->g_do_show_linesM = 0;
 	G->g_catalog_info_nameM = NULL;
 	G->g_system_info_nameM = NULL;
+	G->g_justdbM = 0;
+	G->g_do_dereferenceM = 0;
+	G->g_ignore_slack_installM = 0;
 	*(G->g_gpufieldM) = '\0';
 }
