@@ -56,7 +56,7 @@
 #define PROGNAME                "swverify"
 #define SW_UTILNAME             PROGNAME
 #define SWPROG_VERSION          SWVERIFY_VERSION
-#define WOPT_LAST		217   /* Highest option number */
+#define WOPT_LAST		219   /* Highest option number */
 
 static char progName[] = PROGNAME;
 static char * CHARTRUE = "True";
@@ -198,8 +198,10 @@ fprintf(fp, "%s",
 "      --check-scripts=true|false    Not implemented\n"
 "      --check-volatile=true|false\n"
 "      --show-info    show the matching comparison info to stdout\n"
-"      --catalog-info=NAME  write comparison info to filename NAME\n"
-"      --system-info=NAME  write comparison info to filename NAME\n"
+"      --catalog-info-name=NAME  write comparison info to filename NAME\n"
+"      --system-info-name=NAME  write comparison info to filename NAME\n"
+"      --dereference-symlinks  when obtaining file system info\n"
+"      --ignore-slack-install  ignore Slackware control files when comparing\n"
 "\n"
 "  Verification Options for verifying a directory:\n"
 "\n"
@@ -687,8 +689,10 @@ main(int argc, char **argv)
 		{"check-permissions", 1, 0, 213},
 		{"check-scripts", 1, 0, 214},
 		{"show-info", 0, 0, 215},
-		{"catalog-info", 1, 0, 216},
-		{"system-info", 1, 0, 217},
+		{"catalog-info-name", 1, 0, 216},
+		{"system-info-name", 1, 0, 217},
+		{"dereference-symlinks", 0, 0, 218},
+		{"ignore-slack-install", 0, 0, 219},
 		{0, 0, 0, 0}
              };
 
@@ -1425,6 +1429,12 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		case 217:
 			G->g_system_info_nameM = strdup(optarg);
 			break;
+		case 218:
+			G->g_do_dereferenceM = 1;
+			break;
+		case 219:
+			G->g_ignore_slack_installM = 1;
+			break;
 		default:
 			sw_e_msg(G, "error processing implementation extension option : %s\n",
 				cplob_get_list(w_arglist)[w_option_index]);
@@ -1608,6 +1618,12 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		LCEXIT(sw_exitval(G, target_loop_count, target_success_count));
 	}
 
+	if (does_have_sw_selections(swspecs) == 0) {
+		/* error if there are not selections */
+		sw_e_msg(G, "error: at least one software selection is required\n");
+		LCEXIT(1);
+	}
+
    	current_arg = swc_get_next_target(argv, argc, &optind, 
 						G->g_targetfd_array, 
 					eopt_distribution_target_directory,
