@@ -61,7 +61,8 @@
 extern struct g_pax_read_command g_pax_read_commands[];
 
 #define SWBIS_DEFAULT_REVISION "0.0"
-		
+
+
 static
 int
 construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
@@ -364,7 +365,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
 			swlib_utilname_get(), filename,
 			(int)(h1->c_filesize),
 			(int)(h2->c_filesize));
-
+		SWLIB_FATAL("mismatch of size attribute is fatal");
 	}
 
        	if ((h1->c_dev_maj || h2->c_dev_maj) && 
@@ -597,6 +598,7 @@ write_attribute_file(SWI * swi, ETAR * etar, int ofd, char * filename, char * fi
 	swpl_init_header_root(etar);
 	etar_set_size(etar, strlen(file_data) + 1 /* +1 is the newline */);
 	if (etar_set_pathname(etar, filename)) SWLIB_FATAL("name too long");
+	swpl_set_detected_catalog_perms(swi, etar, REGTYPE);
 	etar_set_chksum(etar);
 
 	/*
@@ -649,7 +651,34 @@ write_catalog_archive_member(SWI * swi, int ofd,
 	etar_init_hdr(etar);
 
 	/*
-	 * Set the basic tar header fields
+	 * write the ../export/ directory itself
+	 */
+
+	swpl_init_header_root(etar);
+	strob_strcpy(buf, SWINSTALL_INCAT_NAME);
+
+	etar_set_mode_ul(etar, (unsigned int)(0755));
+	swpl_set_detected_catalog_perms(swi, etar, DIRTYPE);
+	if (etar_set_pathname(etar, strob_str(buf))) SWLIB_FATAL("name too long");
+	etar_set_typeflag(etar, DIRTYPE);
+	etar_set_size(etar, 0);
+	etar_set_chksum(etar);
+
+	ret = atomicio((ssize_t (*)(int, void *, size_t))uxfio_write,
+				ofd,
+				(void*)(etar_get_hdr(etar)),
+				(size_t)(TARRECORDSIZE));
+
+	if (ret != TARRECORDSIZE) {
+		SWBIS_ERROR_IMPL();
+		SWI_internal_fatal_error();
+		return -1;
+	}
+
+	retval = ret;
+
+	/*
+	 * Now write the catalog.tar file 
 	 */
 	swpl_init_header_root(etar);
 
@@ -662,6 +691,7 @@ write_catalog_archive_member(SWI * swi, int ofd,
 	size = swpl_write_catalog_data(swi, swi->nullfdM, sig_block_start, sig_block_end);
 	etar_set_size(etar, size);
 	if (etar_set_pathname(etar, strob_str(buf))) SWLIB_FATAL("name too long");
+	swpl_set_detected_catalog_perms(swi, etar, REGTYPE);
 	etar_set_chksum(etar);
 
 	/*
@@ -685,7 +715,7 @@ write_catalog_archive_member(SWI * swi, int ofd,
 		SWI_internal_error();
 		retval = -1;
 	} else {
-		retval = size + ret;
+		retval +=  (size + ret);
 	}
 	
 	/*
@@ -840,6 +870,8 @@ construct_execution_phase_script(GB * G, SWI * swi,
 	int ret;
 	char * xxx;
 	STROB * tmp;
+	char * v_target;
+	char * v_command;
 
 	tmp = strob_open(1000);
 
@@ -870,6 +902,13 @@ construct_execution_phase_script(GB * G, SWI * swi,
 	 */
 	xxx = TEVENT(2, -1, SWI_TASK_CTS, "Clear to Send: status=0");
 
+	if (G->g_justdbM == 0) {
+		v_target = swi->swi_pkgM->target_pathM;
+		v_command = pax_read_command;
+	} else {
+		v_target = ".";
+		v_command = "tar tf - 1>/dev/null 2>&1";
+	}
 	strob_sprintf(buf, STROB_DO_APPEND,
 		CSHID
 		"\n"
@@ -887,9 +926,9 @@ construct_execution_phase_script(GB * G, SWI * swi,
 		"esac\n"
 		"\n"
 		,
-		swi->swi_pkgM->target_pathM,
+		v_target,
 		xxx,
-		pax_read_command);
+		v_command);
 
 	/*
 	 * construct the postinstall portion of the execution script
@@ -1087,6 +1126,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	int checkinstall_status;
 	int do_check_abort;
 	int do_enforce_scripts;
+	mode_t modemask;
 	STROB * resolved_path;
 	STROB * namebuf;
 	STROB * newnamebuf;
@@ -1266,13 +1306,26 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * ================================
 	 */
 
+	/* Construct a umask value from the detected mode */
+
+	if (swi->swi_pkgM->installed_catalog_modeM > 0) {
+		mode_t mode;
+		mode = swi->swi_pkgM->installed_catalog_modeM;
+		modemask = (~mode) & (0777);
+		/* fprintf(stderr, "%0o %o\n", (unsigned int)modemask, (unsigned int)mode); */
+	} else {
+		/* default */
+		modemask = 02;
+	}
+
 	if (opt_preview == 0 && retval == 0 && G->g_to_stdout == 0) {
 		swicol_set_task_idstring(swi->swicolM, SWBIS_TS_make_catalog_dir);
 		strob_sprintf(tmp, 0,
-			"(umask 002; mkdir -p \"%s\")</dev/null\n"
+			"(umask %o; mkdir -p \"%s\")</dev/null\n"
 			"sw_retval=$?\n"
 			"dd count=1 bs=512 of=/dev/null 2>/dev/null\n"
 			,
+			(unsigned int)modemask,
 			swi->swi_pkgM->catalog_entryM);
 
 		ret = swicol_rpsh_task_send_script2(
@@ -2717,6 +2770,11 @@ write_target_install_script(GB * G,
 	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_uts ";; *) shls_false_;; esac\n"
 	"sw_retval=$?\n"
 	"swexec_status=$sw_retval\n"
+
+	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_get_catalog_perms ";; *) shls_false_;; esac\n"
+	"sw_retval=$?\n"
+	"swexec_status=$sw_retval\n"
+
 	"case $sw_retval in 0) ;; *) swexec_status=1; sw_retval=1; ;; esac\n"
 	"case $swexec_status in	0) %s ;; *) shls_false_ ;; esac\n" 	/* SW_ANALYSIS_BEGINS */
 	"case $sw_retval in 0) ;; *) swexec_status=1; sw_retval=1; ;; esac\n"
