@@ -2333,7 +2333,9 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				E_DEBUG("");
 				swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 				/* Now reap the task shell events */
+				E_DEBUG("");
 				ret = swicol_rpsh_task_expect(swicol, G->g_swi_event_fd, SWICOL_TL_4);
+				E_DEBUG("done");
 
 			} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) == 0) {
 				/* This section will list the files in installed software */	
@@ -2653,8 +2655,10 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 		swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 
 ENTER_WITH_FAILURE:
-		if ( source_write_pid > 0 )
+		if (swicol_get_master_alarm_status(swicol) == 0 && source_write_pid > 0 ) {
+			E_DEBUG("");
 			swicol_rpsh_wait_for_event(swicol, (STROB *)NULL, G->g_swi_event_fd, SWI_MAIN_SCRIPT_ENDS);
+		}
 
 		E_DEBUG("");
 		if (kill_sshcmd[0]) {
