@@ -1,6 +1,6 @@
 /*  swproglib.c -- general purpose routines common among the sw<utiltities>
 
- Copyright (C) 2006, 2007 Jim Lowe
+ Copyright (C) 2006,2007,2008 Jim Lowe
  All Rights Reserved.
   
  COPYING TERMS AND CONDITIONS:
@@ -132,15 +132,19 @@ determine_ls_list_flags(int attr, struct new_cpio_header * file_hdr, int check_c
 	digs = file_hdr->digsM;
 	if (digs) {
 		if (digs->do_md5 == DIGS_ENABLE_ON ) {
+			E_DEBUG("Turning on md5");
 			ls_verbose |= LS_LIST_VERBOSE_WITH_MD5;
 		}
 		if (digs->do_sha1 == DIGS_ENABLE_ON ) {
+			E_DEBUG("Turning on sha1");
 			ls_verbose |= LS_LIST_VERBOSE_WITH_SHA1;
 		}
 		if (digs->do_sha512 == DIGS_ENABLE_ON ) {
+			E_DEBUG("Turning on sha512");
 			ls_verbose |= LS_LIST_VERBOSE_WITH_SHA512;
 		}
 	} else {
+		E_DEBUG("Turning off digests");
 		ls_verbose &= ~(LS_LIST_VERBOSE_WITH_MD5|LS_LIST_VERBOSE_WITH_SHA1|LS_LIST_VERBOSE_WITH_SHA512);
 	}
 	return ls_verbose;
@@ -429,6 +433,96 @@ alter_catalog_entry(int remove_restore, GB * G, SWICOL * swicol, SWICAT_E * e, i
 	return retval;
 }
 
+static
+int
+parse_ls_ld_output(SWI * swi, char * ls_output)
+{
+	char * line;
+	char * value;
+	char * attribute;
+	int ret;
+	STROB * tmp;
+	char * s;
+	mode_t mode;
+	char * s_mode;
+	char * owner;
+	char * group;
+	
+	/*
+	The line to parse looks something like this
+
+	swinstall: swicol: 315:ls_ld=drwxr-x--- jhl/other 0 2008-10-30 20:46 var/lib/swbis/catalog/
+	*/
+
+	ret = 0;
+	tmp = strob_open(10);
+	line = strob_strtok(tmp, ls_output, "\r\n");
+	while (line) {
+		ret = swevent_parse_attribute_event(line, &attribute, &value);
+		if (ret == 0) {
+			if (strcmp(attribute, "ls_ld") == 0) {
+				char buf[30];
+				/*
+				fprintf(stderr, "attribute=[%s]\n", attribute);	
+				fprintf(stderr, "value=[%s]\n", value);	
+				*/
+				/* Now parse the value to get the perms, owner, and group
+				   The value looks like
+				drwxr-x--- jhl/other 0 2008-10-30 20:46 var/lib/swbis/catalog/
+				 */
+				s_mode = strob_strtok(tmp, value, " ");
+				if (!s_mode) return -1;
+				s = strob_strtok(tmp, NULL, " ");
+				if (!s) return -1;
+				owner = s;
+				s = strchr(s, '/');
+				if (!s) return -1;
+				*s = '\0';
+				s++;
+				group = s;
+				swi->swi_pkgM->installed_catalog_ownerM = strdup(owner);
+				swi->swi_pkgM->installed_catalog_groupM = strdup(group);
+				mode = swlib_filestring_to_mode(s_mode, 0);
+				swi->swi_pkgM->installed_catalog_modeM = mode;
+				if (mode == 0) return -1;				
+				/* Test point
+				taru_mode_to_chars(mode, buf, sizeof(buf), '\0');
+				fprintf(stderr, "[%s] [%s] [%s] [%s]\n", owner, group, s_mode, buf);
+				*/
+				ret = 0;
+				break;
+			} else {
+				fprintf(stderr, "bad message: %s\n", attribute);
+				ret = -1;
+				break;
+			}
+		} else {
+			/* this happens */
+			ret = 0;
+		}
+		line = strob_strtok(tmp, NULL, "\r\n");
+	}
+	strob_close(tmp);
+	return ret;
+}
+
+void
+swpl_set_detected_catalog_perms(SWI * swi, ETAR * etar, int tar_type)
+{
+	mode_t mode;
+	if (swi->swi_pkgM->installed_catalog_ownerM)
+		etar_set_uname(etar, swi->swi_pkgM->installed_catalog_ownerM);
+	if (swi->swi_pkgM->installed_catalog_groupM)
+		etar_set_gname(etar, swi->swi_pkgM->installed_catalog_groupM);
+	mode = swi->swi_pkgM->installed_catalog_modeM;
+	if (mode > 0) {
+		if (tar_type == REGTYPE) {
+			mode &= ~(S_IXUSR|S_IXGRP|S_IXOTH);
+		}
+		etar_set_mode_ul(etar, (unsigned int)(mode));
+	}
+}
+
 int
 swpl_send_null_task(SWICOL * swicol, int ofd, int event_fd, char * msgtag, int retcode)
 {
@@ -871,6 +965,7 @@ swpl_write_single_file_tar_archive(SWI * swi, int ofd, char * name, char * data)
 	swpl_init_header_root(etar);
 	etar_set_size(etar, strlen(data));
 	if (etar_set_pathname(etar, name)) SWLIB_FATAL("name too long");
+	swpl_set_detected_catalog_perms(swi, etar, REGTYPE);
 	etar_set_chksum(etar);
 
 	/*
@@ -2052,11 +2147,6 @@ swpl_update_execution_script_results(SWI * swi, SWICOL * swicol, SCAR ** array)
 	event_start_index = 0;
 
 	E_DEBUG2("event_start_index=%d", event_start_index);
-	/*
-	swicol_print_events(swicol, buf, -1);	
-	fprintf(stderr, "%s", strob_str(buf));
-	swpl_scary_show_array(array);
-	*/
 
 	/*
 	 * loop over the events
@@ -2255,10 +2345,8 @@ swpl_get_utsname_attributes(GB * G, SWICOL * swicol, SWUTS * uts, int ofd, int e
 			TEVENT(2, 1, SWI_ATTRIBUTE, SW_A_os_version   "=\"$(uname -v)\""),
 			TEVENT(2, 1, SWI_ATTRIBUTE, SW_A_architecture "=\"$(shls_run_config_guess)\""),
 			"");
-	/* E_DEBUG2("get_utsname_script=[%s]", strob_str(tmp)); */
 
 	/* TS_uts_query */
-	/* swicol_set_task_idstring(swicol, SWBIS_TS_uts); */
 	ret = swicol_rpsh_task_send_script2(
 		swicol,
 		ofd, 
@@ -2279,11 +2367,6 @@ swpl_get_utsname_attributes(GB * G, SWICOL * swicol, SWUTS * uts, int ofd, int e
 			SWICOL_TL_100 /*timelimit*/);
 			/* 100 seconds needed for cygwin hosts */
 	
-		/*
-		if (swi->debug_eventsM)
-			swicol_show_events_to_fd(swi->swicolM, STDERR_FILENO, -1);
-		*/
-
 		/*
 		 * print the events to memory
 		 */
@@ -2314,6 +2397,77 @@ swpl_get_utsname_attributes(GB * G, SWICOL * swicol, SWUTS * uts, int ofd, int e
 	return ret;
 }
 
+int
+swpl_get_catalog_perms(GB * G, SWI * swi, int ofd, int event_fd)
+{
+	int ret;
+	SWICOL * swicol;
+	STROB * tmp;
+	
+	swicol = swi->swicolM;
+	tmp = strob_open(10);
+
+	strob_sprintf(tmp, 0,
+			CSHID
+			"sw_retval=0\n"
+			"ISC=\"%s\"\n"
+			"LSO=`tar chf - \"$ISC\" 2>/dev/null | tar tvf - | head -1`\n"
+			"%s\n"
+			"dd of=/dev/null 2>/dev/null\n"
+			"exit $sw_retval\n"
+			"%s"		/* nil line */
+			,
+			get_opta(G->optaM, SW_E_installed_software_catalog),
+			TEVENT(2, 1, SWI_ATTRIBUTE, "ls_ld=\"$LSO\""),
+			"");
+
+	/* TS_get_catalog_perms */
+	ret = swicol_rpsh_task_send_script2(
+		swicol,
+		ofd, 
+		512,
+		".",
+		strob_str(tmp), SWBIS_TS_get_catalog_perms
+		);
+
+	if (ret == 0) {
+		ret = etar_write_trailer_blocks(NULL, ofd, 1);
+		if (ret < 0) {
+			fprintf(stderr, "%s: get_catalog_perms(): etar_write_trailer_blocks(): ret=%d\n",
+				swlib_utilname_get(), ret);
+		}
+
+		ret = swicol_rpsh_task_expect(swicol,
+			event_fd,
+			SWICOL_TL_100 /*timelimit*/);
+			/* 100 seconds needed for cygwin hosts */
+		
+		if (ret != 0) {
+			/* FIXME, write error message */
+			return -1;
+		}
+	
+		/*
+		 * print the events to memory
+		 */
+		swicol_print_events(swicol, tmp, swicol->event_indexM);
+		/* fprintf(stderr, "%s\n", strob_str(tmp)); */
+
+		/*
+		 * Parse and Store the ls -ld output into swi
+		 */
+		ret = parse_ls_ld_output(swi, strob_str(tmp));
+		if (ret != 0) {
+			/* FIXME, write error message */
+			return -2;
+		}
+	} else {
+		ret = -3;
+	}
+	strob_close(tmp);
+	return ret;
+}
+
 int
 swpl_determine_tar_listing_verbose_level(SWI * swi)
 {
@@ -2627,7 +2781,6 @@ swpl_get_catalog_entries(GB * G,
 	return retval;
 }
 
-
 int
 swpl_do_list_catalog_entries2(GB * G,
 			VPLOB * swspecs,
@@ -3421,6 +3574,8 @@ swpl_make_verify_command_script_fragment(GB * G,
 		char * pax_write_command_key, int be_silent)
 {
 	int ret;
+	int check_volatile;
+	int is_volatile;
 	STROB * stop_word;
 	STROB * shell_lib_buf;
 	char * name;
@@ -3519,11 +3674,20 @@ swpl_make_verify_command_script_fragment(GB * G,
 	/* priint each file */
 	E_DEBUG("");
 	ix = 0;
+	check_volatile = swextopt_is_option_true(SW_E_check_volatile, G->optaM);
+
 	while ((name=swi_fl_get_path(fl, ix)) != NULL) {
 		if (G->devel_verboseM) {
 			SWLIB_INFO3("INFO; file=[%s] type=[%c]", name, (int)swi_fl_get_type(fl, ix));
 		}
-		strob_sprintf(scriptbuf, STROB_DO_APPEND, "%s\n", name);
+		/* Check the volatile flag */
+		is_volatile = 0;	
+		if (check_volatile == 0) {
+			/* exclude volatile */
+			is_volatile = swi_fl_is_volatile(fl, ix);
+		}
+		if (is_volatile == 0)
+			strob_sprintf(scriptbuf, STROB_DO_APPEND, "%s\n", name);
 		ix++;
 	}
 
@@ -3538,6 +3702,7 @@ swpl_make_verify_command_script_fragment(GB * G,
 	E_DEBUG("");
 	/* write the tar writing command */
 	if (
+		G->g_do_dereferenceM ||
 		strcmp(pax_write_command_key, "tar") == 0 ||
 		strcmp(pax_write_command_key, "gtar") == 0 ||
 		0
@@ -3545,9 +3710,10 @@ swpl_make_verify_command_script_fragment(GB * G,
 		do_tar_key: /* goto label */
 
 		strob_sprintf(scriptbuf, STROB_DO_APPEND,
-			" %s %scf - -b 1 --no-recursion --files-from=- %s\n",
+			" %s %scf - -b 1 %s --no-recursion --files-from=- %s\n",
 			pax_write_command_key,
 			(char*)(G->g_verboseG > SWC_VERBOSE_2 ? "v" : ""),
+			(G->g_do_dereferenceM == 0 ? "": "--dereference"),
 			(be_silent ? "2>/dev/null" : ""));
 	} else if (
 		strcmp(pax_write_command_key, "pax") == 0 ||
@@ -3687,7 +3853,7 @@ swpl_ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose, int * available_a
 
 		/* file_attribute_usage are the TARU_UM_* flags and it returns
 		   the policy in terms of the LS_LIST_VERBOSE flags  */
-		*available_attributes = determine_ls_list_flags(file_attribute_usage, file_hdr, check_contents);
+		*available_attributes |= determine_ls_list_flags(file_attribute_usage, file_hdr, check_contents);
 		/* fprintf(stderr, "=========== %d\n", *available_attributes); */
 
 		/* The contents of the INFO object are first detected and set in the
