@@ -56,7 +56,7 @@
 #define PROGNAME                "swremove"
 #define SW_UTILNAME             PROGNAME
 #define SWPROG_VERSION          SWREMOVE_VERSION
-#define WOPT_LAST		212   /* Highest option number */
+#define WOPT_LAST		213   /* Highest option number */
 
 static char progName[] = PROGNAME;
 static char * CHARTRUE = "True";
@@ -159,6 +159,7 @@ fprintf(fp, "%s",
 "\n"
 "  Operational Options:\n"
 "\n"
+"      --justbd  remove only the installed catalog entry\n"
 "      --allow-ambig  Allow multple packages to be selected by one selection spec\n"
 "      --keep-volatile-files  rename with a suffix e.g. <name>.swbisold\n"
 "      --force  ignore downdate, prerequisites, reinstall etc.\n"
@@ -287,6 +288,7 @@ show_all_sw_selections(VPLOB * swspecs)
 	return 0;
 }
 
+static
 int
 does_have_sw_selections(VPLOB * swspecs)
 {
@@ -294,12 +296,14 @@ does_have_sw_selections(VPLOB * swspecs)
 	vplob_get_nstore(swspecs) > 0 ? 1 : 0;
 }
 
+static
 void
 critical_region_begin(void)
 {
 	swgp_signal_block(SIGINT, (sigset_t *)NULL);
 }
 
+static
 void
 critical_region_end(void)
 {
@@ -638,6 +642,7 @@ main(int argc, char **argv)
 		{"remove-volatile", 1, 0, 210},
 		{"keep-volatile-files", 0, 0, 211},
 		{"cleansh", 0, 0, 212},
+		{"justdb", 0, 0, 213},
 		{0, 0, 0, 0}
              };
 
@@ -708,6 +713,7 @@ main(int argc, char **argv)
 		{"remove-volatile", 1, 0, 210},
 		{"keep-volatile-files", 0, 0, 211},
 		{"cleansh", 0, 0, 212},
+		{"justdb", 0, 0, 213},
 		{0, 0, 0, 0}
              };
 	
@@ -1326,10 +1332,13 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			E_DEBUG("");
 			set_opta(opta, SW_E_swbis_remove_volatile, "rename");
 			break;
-		case 212: /* WOPT_LAST */
+		case 212:
 			E_DEBUG("");
 			G->g_do_cleanshM = 1;
 			break;
+		case 213: /* WOPT_LAST */
+			G->g_justdbM = 1;
+			break;
 		default:
 			sw_e_msg(G, "error processing implementation extension option : %s\n",
 				cplob_get_list(w_arglist)[w_option_index]);
@@ -1513,6 +1522,13 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		LCEXIT(sw_exitval(G, target_loop_count, target_success_count));
 	}
 
+	/*
+	if (does_have_sw_selections(swspecs) == 0) {
+		sw_e_msg(G, "error: at least one software selection is required\n");
+		LCEXIT(1);
+	}
+	*/
+
    	current_arg = swc_get_next_target(argv, argc, &optind, 
 						G->g_targetfd_array, 
 					eopt_distribution_target_directory,
@@ -2324,12 +2340,6 @@ ENTER_WITH_FAILURE:
 		E_DEBUG("");
 		swicol_rpsh_wait_for_event(swicol, (STROB *)NULL, G->g_swi_event_fd, SWI_MAIN_SCRIPT_ENDS);
 ENTER_WITH_FAILURE2:
-	/*
-		if (f_retval == 0)
-			swicol_rpsh_wait_for_event(swicol, (STROB *)NULL, G->g_swi_event_fd, SWI_MAIN_SCRIPT_ENDS);
-		else
-			swc_shutdown_logger(G, SIGABRT);
-	*/
 
 		E_DEBUG("");
 		if (kill_sshcmd[0]) {
