@@ -86,6 +86,67 @@ print_lines(char * name, char * pref, STRAR * ar)
 	return;
 }
 
+static
+char *
+discern_name(char * line, int * len)
+{
+	char * s;
+	char * delim =  "[linkname=";
+
+	*len = 0;
+	s = strstr(line, delim);
+	if (s == NULL) {
+		/* error */
+		return NULL;
+	}
+	*len = (int)(s - line);		
+	return line;
+}
+
+static
+int
+remove_duplicate_files(STRAR * meta)
+{
+	int im;
+	char * m_s;
+	char * name;
+	char * prevname;
+	int len;
+	int prevlen;
+
+	prevname = NULL;
+	prevlen = 0;
+	im = 0;
+	m_s = strar_get(meta, im++);
+	while (m_s) {
+		/* fprintf(stderr, "%s\n", m_s); */
+		name = discern_name(m_s, &len);
+		if (!name)
+			return -1;
+
+		if (name && prevname) {
+			if (strncmp(name, prevname, len) == 0) {
+				/* remove the line with the lower
+				   memory address since this should
+				   indicate the first file is the INFO
+				   file. */
+				if (name < prevname) {
+					fprintf(stderr, "REMOVING [%s] index %d\n", name, im-1);
+					strar_remove_index(meta, im-2);
+				} else {
+					fprintf(stderr, "REMOVING [%s] index %d\n", name, im-2);
+					strar_remove_index(meta, im-1);
+				}
+				im--;
+			}
+		}
+		m_s = strar_get(meta, im++);
+		prevname = name;
+		prevlen = len;
+	}
+	return 0;
+}
+
 static
 STRAR *
 linize(char * text)
@@ -246,8 +307,6 @@ looper_locked_region(STROB * buf, int vlv)
 	return strob_str(buf);
 }
 
-
-
 static
 int
 get_name_len(char * line)
@@ -328,7 +387,15 @@ compare_diff(GB * G, char * host, char * swspec_string, char * target_path, STRA
 	s_s = strar_get(sys, is);
 	while (m_s) {
 		E_DEBUG("");
-		if (m_s && s_s && strcmp(m_s, s_s) == 0) {
+		if (
+			G->g_ignore_slack_installM &&
+			(
+			 	strstr(m_s, "./install/") == m_s ||
+				strstr(m_s, "./install ") == m_s
+			)
+		) {
+			im++;
+		} else if (m_s && s_s && strcmp(m_s, s_s) == 0) {
 			/* good, lines match */
 			im++;			
 			is++;			
@@ -548,8 +615,9 @@ compare_fileset(GB * G, char * swspec_string, char * target_path, SWUTS * uts, S
 	if (G->g_system_info_nameM)
 		print_lines(G->g_system_info_nameM, "", sys_str);
 
-	/* Now compare these line by line */
+	remove_duplicate_files(meta_str);
 
+	/* Now compare these line by line */
 	ret = compare_diff(G, G->g_target_terminal_host, swspec_string,
 				target_path, meta_str, sys_str, G->g_do_show_linesM);
 
@@ -1025,7 +1093,7 @@ swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			strob_str(btmp),
 			strob_strlen(btmp)
 			);
-					
+
 	if (swicol_get_master_alarm_status(swicol) != 0 ||
 		 ret != (int)strob_strlen(btmp)
 	) {
