@@ -24,6 +24,8 @@
 #define swobjfiles_i_hxx
 
 extern "C" {
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
 #include "swuser_config.h"
 }
 
@@ -61,6 +63,13 @@ extern "C" {
 
 #define INFO_SIZE_BLANK	"\040\040\040\040\040\040\040\040"  // Eight (8) Spaces
 
+/*
+#define E_DEBUG(format) SWBISERROR("DEBUG", format)
+#define E_DEBUG2(format, arg) SWBISERROR2("DEBUG", format, arg)
+#define E_DEBUG3(format, arg, arg1) \
+ 			SWBISERROR3("DEBUG", format, arg, arg1)
+*/
+
 class swObjFiles;
 class swObjFiles_i:  public swExStruct_i
 {
@@ -470,6 +479,7 @@ class swObjFiles_i:  public swExStruct_i
 							(int)UCHAR_MAX,
 							(int)UCHAR_MAX);
 		while (next_line){
+			E_DEBUG2("next_line=[%s]", next_line);
 			swmd = psf->swdeffile_linki_find_by_parserline(NULL,
 								next_line);
 			SWLIB_ASSERT(swmd != NULL);
@@ -491,6 +501,7 @@ class swObjFiles_i:  public swExStruct_i
 			swat = (static_cast<swDefinition*>(swmd))->findAttribute(SW_A_path);
 			if (swat) {
 				path = swat->get_value(NULL);
+				E_DEBUG2("path=[%s]", path);
 			} else {
 				path = NULL;
 			}
@@ -506,11 +517,12 @@ class swObjFiles_i:  public swExStruct_i
 			if (
 				get_opta_array() == NULL ||
 				::swextopt_is_option_true(SW_E_swbis_check_duplicates, get_opta_array())
-			)
+			) {
+				E_DEBUG("finding duplicates");
 				did_find_duplicate = check_for_storage_section_duplicates(filedeflist, pathlist, path, basenames);
-			else
+			} else {
 				did_find_duplicate = 0;
-
+			}
 			swmd_def = static_cast<swDefinition*>(swmd);
 			//
 			// The static cast above is safe because the type assertion
@@ -526,6 +538,7 @@ class swObjFiles_i:  public swExStruct_i
 				// Here, (swDefinition*)(swmd) represents the current last
 				// duplicate found so far.
 				//
+				E_DEBUG("setting storage status SWDEF_STATUS_DUP");
 				swmd_def->set_storage_status(SWDEF_STATUS_DUP);
 			}	
 
@@ -533,6 +546,7 @@ class swObjFiles_i:  public swExStruct_i
 				"swObjfiles_i::process_files_step1: next_line=[%s] path=%s\n", next_line, path ? path : "");
 	
 			if (path) {
+				E_DEBUG("");
 				cplob_add_nta(filedeflist, (char*)swmd_def);
 				cplob_add_nta(pathlist, (char*)path);
 				tmpname = ::strrchr(path, '/');
@@ -560,6 +574,7 @@ class swObjFiles_i:  public swExStruct_i
 			// object. Terminate the linked list at the last
 			// file or control_file.
 			//
+			E_DEBUG("");
 			static_cast<swDefinition*>(previous_swmd)
 							->set_next(NULL);
 			info->swdeffile_linki_set_tail(
@@ -571,6 +586,7 @@ class swObjFiles_i:  public swExStruct_i
 			//
 			;
 		}
+		E_DEBUG("");
 		cplob_shallow_close(filedeflist);
 		cplob_shallow_close(pathlist);
 		strob_close(basenames);
@@ -944,7 +960,7 @@ class swObjFiles_i:  public swExStruct_i
 
 				if (::strcmp(pkgname, "INFO") != 0) 
 				{
-					if (swsdflt_get_attr_group("product",
+					if (swsdflt_get_attr_group(SW_A_product,
 								pkgname)
 							!= CONTROLFILE_EXT &&
 						strcmp(pkgname, "install")	&&
@@ -1483,6 +1499,7 @@ class swObjFiles_i:  public swExStruct_i
 
 		current_path_p = path_array;
 		while(*current_path_p) {
+			E_DEBUG3("current_path :: incoming_path  [%s] :: [%s]", *current_path_p, incoming_path);
 			ret = swlib_dir_compare(*current_path_p, incoming_path, SWC_FC_NOAB);
 			if (ret == 0) {
 				//
@@ -1502,19 +1519,22 @@ class swObjFiles_i:  public swExStruct_i
 
 				fprintf(stderr, "swpackage: warning: duplicate file definition: %s\n", incoming_path);
 				if (duplicate_def->get_storage_status() == SWDEF_STATUS_DUP) {
-					duplicate_def->set_storage_status(SWDEF_STATUS_IGN);
+					E_DEBUG("GOT ONE: 1");
+					// duplicate_def->set_storage_status(SWDEF_STATUS_IGN);
 					// fprintf(stderr, "eraseme: case SWDEF_STATUS_IGN: [%s]\n", incoming_path);
 				} else if (duplicate_def->get_storage_status() == SWDEF_STATUS_DUP0) {
 					//
 					// Normal path for 1 or more duplicates. 
 					//
 					// fprintf(stderr, "eraseme: case SWDEF_STATUS_DUP0: [%s]\n", incoming_path);
+					E_DEBUG("GOT ONE: 2");
 					;
 				} else if (duplicate_def->get_storage_status() == SWDEF_STATUS_NOM
 					&& got_first_duplicate == 0) {
 					//
 					// This is the first occurance.
 					//
+					E_DEBUG("GOT ONE: 3");
 					duplicate_def->set_storage_status(SWDEF_STATUS_DUP0);
 					// fprintf(stderr, "eraseme: case SWDEF_STATUS_DUP0: [%s]\n", incoming_path);
 					got_first_duplicate = 1;
@@ -1523,6 +1543,7 @@ class swObjFiles_i:  public swExStruct_i
 				}
 				
 			} else {
+				E_DEBUG("");
 				// fprintf(stderr, "eraseme swpackage: no duplicate here [%s] [%s]\n", incoming_path, *current_path_p);
 				;
 			}
