@@ -93,6 +93,7 @@ public:
     virtual void list_insert(swMetaData * swmd, swMetaData * location);
     virtual int list_add_if_new(swMetaData * swmd);
     virtual void list_replace(swMetaData * swmd);
+    virtual void list_replace_if_not_explicitly_set(swMetaData * swmd);
     
     swMetaData * get_attribute_by_index(int n);
     char * 	 get_parserline_by_index(int n);
@@ -111,7 +112,7 @@ public:
     virtual void set_path_attribute(char * source);
     virtual void set_tag_attribute(void);
 
-    void merge(swDefinition * source, int do_unconditionally);
+    void merge(swDefinition * source, int do_all, int do_not_replace);
     swMetaData *  findAttribute(char * keyword);
     swMetaData *  find_by_ino(int offset_key);
     swMetaData *  find_by_p_offset(int offset_key);
