@@ -229,18 +229,6 @@ public:
 		return static_cast<swMetaData*>(NULL);
 	}
 
-
-	//swMetaData *
-	//swdeffile_linki_find_by_ino(swDefinition * relhead, int offset)
-	//{
-	//	swMetaData * ret;
-	//	ret = swdeffile_linki_find_n(relhead, offset, 
-	//		&swMetaData::get_ino,
-	//		&swDefinition::find_by_ino
-	//		);
-	//	return ret;
-	//}
-
 	swMetaData *
 	swdeffile_linki_find_by_parserline(swDefinition * relhead, char * keyline)
 	{
@@ -519,16 +507,12 @@ public:
 	}
 	int swFileMapSetCurrentOffset(int offset) { return swfilemapM->swFileMapSetCurrentOffset(offset); }
 	int swFileMapReset(void) { return swfilemapM->swFileMapReset(); }
-
-	// char * swdefinitionfile_dump_string_s(char * prefix);
-
-protected:
-	//swMetaData * makeDefinition_i(char * parser_line, swMetaData * swdef);
+        int determine_status_for_writing(swDefinition * swmd);
 
 private:
 
 	intmax_t write_archive_member_data(struct new_cpio_header *file_hdr0,
-			      		int out_file_des, int (swDefinitionFile::*fout)(int), enum archive_format archive_format_out)
+		      		int out_file_des, int (swDefinitionFile::*fout)(int), enum archive_format archive_format_out)
 	{
 		intmax_t retval = 0;
 		intmax_t ret = 0;
@@ -593,6 +577,7 @@ private:
 
 
     void init(void);
+    int merge_duplicates(swDefinition * swmd);
     int run_parser_(int atlevel, int mark_up_flag, int * memfileindex_up);
     int open_parser_common (int ifd, int ofd, int filesize);
 };
