@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,16 +17,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 
 #ifndef swpackagedir_19980601jhl_h
 #define swpackagedir_19980601jhl_h
 
+extern "C" {
+#include "swuser_config.h"
+}
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <limits.h>
 #include <tar.h>
 #include "swpackagefile.h"
 
@@ -41,8 +46,8 @@ class swPackageDir : public swPackageFile
 	virtual void	swfile_set_default_statbuf(void);
 
 
-	virtual int xFormat_write_file(void) {
-		int ret;
+	virtual intmax_t xFormat_write_file(void) {
+		intmax_t ret;
 		char * name;
 
 		name = swfile_get_package_filename();	
