@@ -50,6 +50,8 @@ extern "C" {
 #include "debug_config.h"
 }
 
+// #define SWPACKAGEFILENEEDDEBUG 1
+
 #ifdef SWPACKAGEFILENEEDDEBUG
 #define SWPACKAGEFILE_DEBUG(format) SWBISERROR("SWPACKAGEFILE DEBUG: ", format)
 #define SWPACKAGEFILE_DEBUG2(format, arg) SWBISERROR2("SWPACKAGEFILE DEBUG: ", format, arg)
@@ -413,7 +415,7 @@ class swPackageFile :  public swAttribute
 
 	int swfile_read_next_regfile_header (void) {
 		int ret;
-		while ( ((ret=swfile_read_next_archive_header())==512) && xFormat_get_tar_typeflag() != '0');
+		while ( ((ret=swfile_read_next_archive_header())==512) && xFormat_get_tar_typeflag() != '0') { ; }
 		if (ret != 512) return -1;    
 		return ret;
 	}
@@ -713,7 +715,7 @@ class swPackageFile :  public swAttribute
 			return -2;
 		}
 
-		source = swdef->find("source");
+		source = swdef->find(SW_A_source);
 		no_stat = swdef->get_no_stat();
 
 		if (!source) {
@@ -780,7 +782,7 @@ class swPackageFile :  public swAttribute
 				tmp_control_path);
 			
 			swfile_set_package_filename(package_path);
-			source = swdef->find("source"); // This line fixed a core dump.
+			source = swdef->find(SW_A_source); // This line fixed a core dump.
 			swfile_set_source_filename(source);
 			if ((ret=swlib_unexpand_escapes2(package_path))) {
 				fprintf(stderr, "%s: error expanding escapes for package_path ( %s ) ret=%s\n",
@@ -1122,6 +1124,15 @@ class swPackageFile :  public swAttribute
 		unsigned long int gid;
 		unsigned long int dev;
 
+		if (swdef->get_storage_status() == SWDEF_STATUS_DUP) {
+			//
+			// This software definition is a duplicate and is *not* the
+			// first one (the first one is the one that survives and has
+			// implicit file stats set for it).
+			//
+			return 0;
+		}
+
 		//
 		// Make the find() routine skip attributes that have been vremove()'ed.
 		// if logical_find == 1 then skip the vremove'ed attributes.
