@@ -8,7 +8,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 
@@ -233,7 +233,7 @@ glbindex_find_by_swpath_ex(SWHEADER * global_index, SWPATH_EX * swpath_ex)
 	STROB * object_keyword;
 
 	swheader = global_index;
-	swheader_store_state(swheader);
+	swheader_store_state(swheader, NULL);
 
 	swheader_set_current_offset(swheader, 0 /* the beginning */);
 
@@ -271,7 +271,7 @@ glbindex_find_by_swpath_ex(SWHEADER * global_index, SWPATH_EX * swpath_ex)
 	 * next_line should be the distribution object
 	 */
 
-	if (strar_max_index(control_dir_list) > 3) {
+	if (strar_num_elements(control_dir_list) > 3) {
 		/*
 		 * Looking for a fileset object
 		 * First search for the product with the control directory
@@ -298,6 +298,6 @@ glbindex_find_by_swpath_ex(SWHEADER * global_index, SWPATH_EX * swpath_ex)
 
 	strar_close(control_dir_list);
 	strob_close(object_keyword);
-	swheader_restore_state(swheader);
+	swheader_restore_state(swheader, NULL);
 	return ret; 
 }
