@@ -1,14 +1,24 @@
 #ifndef sw_h_20050210
 #define sw_h_20050210
 
+	/* POSIX level values for swlist */
+#define SW_LEVEL_V_FILE		1
+#define SW_LEVEL_V_CONTROL_FILE	2
+#define SW_LEVEL_V_FILESET	3
+#define SW_LEVEL_V_PRODUCT	4
+#define SW_LEVEL_V_SUBPRODUCT	5
+#define SW_LEVEL_V_BUNDLE	6
+#define SW_LEVEL_V_DISTRIBUTION	7
+#define SW_LEVEL_V_HOST		8
+
 	/* POSIX result values  -- <result> attribute */
 #define SW_RESULT_NONE		"none"
 #define SW_RESULT_SUCCESS	"success"
 #define SW_RESULT_WARNING	"warning"
 #define SW_RESULT_FAILURE	"failure"
 
-	/* POSIX installation states   -- <state> attribute */
-#define SW_STATE_UNSET		"__unset__"
+	/* POSIX fileset states   -- <state> attribute */
+#define SW_STATE_UNSET		"__unset__"  /* Impl extension */
 #define SW_STATE_CONFIGURED	"configured"
 #define SW_STATE_INSTALLED	"installed"
 #define SW_STATE_CORRUPT	"corrupt"
@@ -16,6 +26,18 @@
 #define SW_STATE_AVAILABLE	"available"
 #define SW_STATE_TRANSIENT	"transient"
 
+	/*  Swbis Installed_software catalog states,
+	    These are the names of the sequence directory
+	    in the installed_software_catalog */
+
+#define SWBIS_ISTATE_OK			"0"
+#define SWBIS_ISTATE_NOT_OK		"1"
+#define SWBIS_ISTATE_TRANSIENT		"2"
+#define SWBIS_ISTATE_CORRUPT		"3"
+#define SWBIS_ISTATE_REMOVED		"4"
+
+#define SWBIS_STATUS_COMMAND_NOT_FOUND	"126"
+
 	/* POSIX (IEEE 1387.2) type letters for the 'type' attribute */
 #define SW_ITYPE_f	'f'	/* Reg */	
 #define SW_ITYPE_d	'd'	/* Dir */
@@ -25,16 +47,19 @@
 #define SW_ITYPE_c	'c'	/* char device */
 #define SW_ITYPE_p	'p'	/* fifo */
 #define SW_ITYPE_x	'x'	/* Not posix, C701 extension for 'to be deleted file */
+#define SW_ITYPE_y	'y'	/* Not posix, Not C701, internal use only, means not dumped */
 
 #define SW_CATALOG "catalog"		/* The name of the POSIX catalog directory */
 
 #define SW_A_INDEX		"INDEX"	     /* Distribution INDEX file */
 #define SW_A_INSTALLED		"INSTALLED"  /* installed_software file [swbis specific] */
+#define SW_A__INSTALLED		"_INSTALLED" /* transient name for INSTALLED */
 #define SW_A_INFO		"INFO"
 #define SW_A_OPTION		"OPTION"
 #define SW_A_PSF		"PSF"
 #define SW_A_PSFi		"PSFi"
 #define SW_A__END		"_END"
+#define SW_A_adjunct_md5sum	"adjunct_md5sum"
 #define SW_A_all_filesets	"all_filesets"
 #define SW_A_all_patches	"all_patches"
 #define SW_A_ancestor		"ancestor"
@@ -58,6 +83,7 @@
 #define SW_A_compression_type	"compression_type"
 #define SW_A_configure		"configure"
 #define SW_A_contents		"contents"
+#define SW_A_rpm_conflicts	"rpm_conflicts"
 #define SW_A_controlsh		"control.sh"  /* installed software catalog control script [swbis specific] */
 #define SW_A_control_directory	"control_directory"
 #define SW_A_control_file	"control_file"
@@ -70,6 +96,7 @@
 #define SW_A_directory		"directory"
 #define SW_A_distribution	"distribution"
 #define SW_A_end		"end"
+#define SW_A_exclude		"exclude"
 #define SW_A_exclude_arch	"exclude_arch"
 #define SW_A_exclude_os		"exclude_os"
 #define SW_A_exclusive_arch	"exclusive_arch"
@@ -98,6 +125,7 @@
 #define SW_A_location		"location"
 #define SW_A_machine_type	"machine_type"
 #define SW_A_major		"major"
+#define SW_A_md5sum		"md5sum"
 #define SW_A_media		"media"
 #define SW_A_media_sequence_number		"media_sequence_number"
 #define SW_A_media_type		"media_type"
@@ -125,6 +153,7 @@
 #define SW_A_release		"release"
 #define SW_A_request		"request"
 #define SW_A_result		"result"
+#define SW_A_rpm_requires	"rpm_requires"
 #define SW_A_revision		"revision"
 #define SW_A_rpm_buildarchs	"rpm_buildarchs"
 #define SW_A_rpm_default_prefix	"rpm_default_prefix"
@@ -138,6 +167,8 @@
 #define SW_A_sequence_number	"sequence_number"
 #define SW_A_signature		"signature"
 #define SW_A_size		"size"
+#define SW_A_sha1sum		"sha1sum"
+#define SW_A_sha512sum		"sha512sum"
 #define SW_A_source		"source"
 #define SW_A_source_package	"source_package"
 #define SW_A_sourcerpm		"sourcerpm"
