@@ -3,7 +3,7 @@
 
 #include "rpmbis.h"
 
-#define SWMAP_MAX_LENGTH 161
+#define SWMAP_MAX_LENGTH 163  /*  i.e. because the last tag is 1163 */
 
 #define RPMPSF_DEF_DFILES		"rpm_dfiles"     /* FIXME rename these? */
 #define RPMPSF_FILESET_SOURCE		"sources"
@@ -27,6 +27,9 @@ typedef struct {
 #define SWATMAP_ATT_Header		0       /* Use the package attributes */
 #define SWATMAP_ATT_Signature		1       /* Use the signature attributes */
 
+#define SWATTMAP_MAP_NA			"NA"    /* Mapping Not applicable */
+#define SWATTMAP_MAP_NONE		"NONE"  /* Maping undefined */
+
 struct swattributes_map
         {
 		int rpmtag_number;      /* rpm tag number           */
@@ -85,7 +88,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_RELEASE", 
 		"-d -l distribution -a release",
 		"",	
-		"vendor_tag"
+		"product.vendor_tag"
 		}},
 	{ 
 		1003, RPM_STRING_TYPE, 0, -1, 1,	   /* Not LSB sanctioned */
@@ -93,7 +96,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_SERIAL", 
 		"-d -l product -a number",
 		"",	
-		""
+		SWATTMAP_MAP_NONE
 		}},
 	{ 
 		1004, RPM_I18NSTRING_TYPE, 1, 1, 1,
@@ -101,7 +104,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_SUMMARY", 
 		"-d -l distribution -a title",
 		"",	
-		""
+		"product.title"
 		}},
 	{ 
 		1005, RPM_I18NSTRING_TYPE, 1, 1, 1,
@@ -109,7 +112,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_DESCRIPTION", 
 		"-d -l distribution -a description",
 		"",	
-		"description"
+		"product.description"
 		}},
 	{ 
 		1006, RPM_INT32_TYPE, 1, 0, 1,
@@ -117,7 +120,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_BUILDTIME", 
 		"-d -l distribution -a create_time",
 		"",	
-		""
+		"distribution.create_time"
 		}},
 	{ 
 		1007, RPM_STRING_TYPE, 1, 0, 1,
@@ -125,7 +128,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_BUILDHOST", 
 		"-d -l product -a build_host",
 		"",	
-		""
+		"product.build_host"
 		}},
 	{ 
 		1008, RPM_INT32_TYPE, 0, -1, 1,
@@ -133,31 +136,31 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"RPMTAG_INSTALLTIME", 
 		"-d -l product -a mod_time",
 		"",	
-		""
+		"product.mod_time"
 		}},
 	{ 
 		1009, RPM_INT32_TYPE, 1, 1, 1,
 		{
 		"RPMTAG_SIZE", 
-		"-d -l distribution -a size",
+		"-d -l fileset -a size",
 		"",	
-		""
+		"fileset.size"
 		}},
 	{ 
-		1010, RPM_STRING_TYPE, 0, -1,  1,  /* Not LSB sanctioned */
+		1010, RPM_STRING_TYPE, 0, -1,  1,  /* LSB Informational */
 		{
 		"RPMTAG_DISTRIBUTION", 
 		"-d -l distribution -a dfiles", 	   /* swbis */
 		"",	
-		""
+		"distribution.dfiles"
 		}},
 	{ 
-		1011, RPM_STRING_TYPE, 0, -1,  1,  /* Not LSB sanctioned */
+		1011, RPM_STRING_TYPE, 0, -1,  1,  /* Informational */
 		{
 		"RPMTAG_VENDOR", 
 		"-d -l vendor -a title *,vq=seller",       /* swbis */
 		"",	
-		""
+		"vendor.tag"
 		}},
 	{ 
 		1012 , RPM_BIN_TYPE, 0, -1, 1,
@@ -248,14 +251,14 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	 1023, RPM_STRING_TYPE, -1, -1, 1,
+ 	 	 1023, RPM_STRING_TYPE, 1, 0, 1,
 		{"RPMTAG_PREIN",  
 		"-d -l control_file -a preinstall *", /* source stored in control_file.contents */ 
 		"",	
 		""
 		}},
 	{
- 	 	 1024, RPM_STRING_TYPE, -1, -1, 1,
+ 	 	 1024, RPM_STRING_TYPE, 1, 0, 1,
 		{
 		"RPMTAG_POSTIN",  
 		"-d -l control_file -a postinstall *", /* source stored in control_file.contents */   
@@ -263,7 +266,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	 1025, RPM_STRING_TYPE, -1, -1, 1,
+ 	 	 1025, RPM_STRING_TYPE, 1, 0, 1,
 		{
 		"RPMTAG_PREUN",  
 		"-d -l control_file -a unpreinstall *",  /* source stored in control_file.contents */   
@@ -736,7 +739,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"" 
 		}},
 	{
- 	 	1085, RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1085, RPM_STRING_TYPE, 1, 0, 1,
 		{
 		"RPMTAG_PREINPROG",  
 		"-d -l control_file -a interpreter preinstall",
@@ -744,7 +747,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1086, RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1086, RPM_STRING_TYPE, 1, 0, 1,
 		{
 		"RPMTAG_POSTINPROG",  
 		"-d -l control_file -a interpreter postinstall",
@@ -752,31 +755,31 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1087 , RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1087 , RPM_STRING_TYPE, 1, 0, 1,
 		{
-		"RPMTAG_PREUNPROG",  
+		"RPMTAG_PREUNPROG",
 		"-d -l control_file -a interpreter unpreinstall",
 		"",	
 		""
 		}},
 	{
- 	 	 1088, RPM_STRING_TYPE, -1, -1, 1,
+ 	 	 1088, RPM_STRING_TYPE, 1, 0, 1,
 		{
-		"RPMTAG_POSTUNPROG",  
+		"RPMTAG_POSTUNPROG",
 		"-d -l control_file -a interpreter unpostinstall",
 		"",	
 		""
 		}},
 	{
- 	 	1089, RPM_STRING_ARRAY_TYPE, -1, -1, 0,
+ 	 	1089, RPM_STRING_ARRAY_TYPE, 0, -1, 0,
 		{
-		"RPMTAG_BUILDARCHS",  
+		"RPMTAG_BUILDARCHS",
 		"-d -l distribution -a rpm_buildarchs",
 		"",	
 		""
 		}},
 	{
- 	 	1090, RPM_STRING_ARRAY_TYPE, -1, -1, 0,
+ 	 	1090, RPM_STRING_ARRAY_TYPE, 1, 0, 0,
 		{
 		"RPMTAG_OBSOLETENAME",  
 		"-d -l distribution -a rpm_obsoletes",
@@ -856,7 +859,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1100,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1100,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_TRIGGERRIN",  
 		"",
@@ -864,7 +867,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1101,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1101,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_TRIGGERPOSTUN",  
 		"",
@@ -872,7 +875,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1102,  RPM_STRING_TYPE, -1, -1,  1, /* Internal */
+ 	 	1102,  RPM_STRING_TYPE, 0, -1,  1, /* Internal */
 		{
 		"RPMTAG_TRIGGERPOSTUNl",  
 		"",
@@ -880,7 +883,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1103,  RPM_STRING_TYPE, -1, -1,  1, /* Internal */
+ 	 	1103,  RPM_STRING_TYPE, 0, -1,  1, /* Internal */
 		{
 		"RPMTAG_AUTOREQ",
 		"",
@@ -888,7 +891,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1104,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1104,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_AUTOPROV",
 		"",
@@ -896,7 +899,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1105,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1105,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_CAPABILITY",
 		"",
@@ -904,7 +907,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1106,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1106,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_SOURCEPACKAGE",
 		"",
@@ -912,7 +915,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1107,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1107,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_OLDORIGFILENAMES",
 		"",
@@ -920,7 +923,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1108,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1108,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_BUILDPREREQ",
 		"",
@@ -928,8 +931,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1109,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
-		/* Last tag of rpm-3.0 Circa 1999-04-14 */
+ 	 	1109,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */ /* Last tag of rpm-3.0 Circa 1999-04-14 */
 		{
 		"RPMTAG_BUILDREQUIRES",
 		"",
@@ -937,7 +939,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1110,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1110,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_BUILDCONFLICTS",
 		"",
@@ -945,7 +947,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1111,  RPM_STRING_ARRAY_TYPE, -1, -1,  0, /* Internal */
+ 	 	1111,  RPM_STRING_ARRAY_TYPE, 0, -1,  0, /* Internal */
 		{
 		"RPMTAG_BUILDMACROS",
 		"",
@@ -1017,7 +1019,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1120,  RPM_STRING_ARRAY_TYPE, -1, -1, 0,
+ 	 	1120,  RPM_STRING_ARRAY_TYPE, 0, -1, 0,
 		{
 		"RPMTAG_ORIGBASENAMES",
 		"",
@@ -1025,7 +1027,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1121,  RPM_STRING_ARRAY_TYPE, -1, -1, 0,
+ 	 	1121,  RPM_STRING_ARRAY_TYPE, 0, -1, 0,
 		{
 		"RPMTAG_ORIGDIRNAMES",
 		"",
@@ -1041,7 +1043,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1123,  RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1123,  RPM_STRING_TYPE, 0, -1, 1,
 		{
 		"RPMTAG_DISTURL",
 		"",
@@ -1072,7 +1074,8 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		"",	
 		""
 		}},
-	{  /* 1127 is the first free tag of rpm-3.0.5 */
+	{
+	   /* 1127 is the first free tag of rpm-3.0.5 */
 	   /* 1127 is called RPMTAG_MULTILIBS in rpm-4.0.2 */
 	   /* 1127 is called RPMTAG_INSTALLCOLOR in rpm-4.4.1 */
  	 	1127,  RPM_STRING_TYPE, -1, -1, 0,
@@ -1083,7 +1086,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1128,  RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1128,  RPM_STRING_TYPE, 0, -1, 1,
 		{
 		"RPMTAG_INSTALLTID",
 		"",
@@ -1091,7 +1094,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1129,  RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1129,  RPM_STRING_TYPE, 0, -1, 1,
 		{
 		"RPMTAG_REMOVETID",
 		"",
@@ -1099,7 +1102,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1130,  RPM_STRING_TYPE, -1, -1, 1,
+ 	 	1130,  RPM_STRING_TYPE, 0, -1, 1,
 		{
 		"RPMTAG_SHA1RHN",		/* Internal Obsolete */
 		"",
@@ -1107,7 +1110,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1131,  RPM_STRING_TYPE, 0, 0, 1,
+ 	 	1131,  RPM_STRING_TYPE, 1, 0, 1,  /* Deprecated by LSB */
 		{
 		"RPMTAG_RHNPLATFORM",
 		"",
@@ -1123,8 +1126,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1133,  RPM_STRING_ARRAY_TYPE, 0, -1, 0,
-		/* in rpm-4.1 designated as: !< placeholder (SuSE) */
+ 	 	1133,  RPM_STRING_ARRAY_TYPE, 0, -1, 0, /* in rpm-4.1 designated as: !< placeholder (SuSE) */
 		{
 		"RPMTAG_PATCHESNAME",        
 		"",
@@ -1132,8 +1134,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1134,  RPM_STRING_ARRAY_TYPE, 0, -1, 0,
-		/* in rpm-4.1 designated as: !< placeholder (SuSE) */
+ 	 	1134,  RPM_STRING_ARRAY_TYPE, 0, -1, 0, /* in rpm-4.1 designated as: !< placeholder (SuSE) */
 		{
 		"RPMTAG_PATCHESFLAGS",
 		"",
@@ -1141,8 +1142,7 @@ const struct swattributes_map swdef_pkg_maptable[] = {
 		""
 		}},
 	{
- 	 	1135,  RPM_STRING_ARRAY_TYPE, 0, -1, 0,
-		/* in rpm-4.1 designated as: !< placeholder (SuSE) */
+ 	 	1135,  RPM_STRING_ARRAY_TYPE, 0, -1, 0, /* in rpm-4.1 designated as: !< placeholder (SuSE) */
 		{
 		"RPMTAG_PATCHESVERSION",
 		"",
