@@ -18,21 +18,37 @@
 #define SW_SOC_DOES_NOT_EXIST 		31
 #define SW_SOC_IS_CORRUPT 		32
 #define SW_SOC_CREATED 			34
+#define SW_CONFLICTING_SESSION_IN_PROGRESS	35
+#define SW_SOC_LOCK_FAILURE		36
+#define SW_SOC_IS_READ_ONLY		37
 #define SW_SOC_IS_REMOTE		38
 #define SW_SOC_IS_SERIAL 		40
+#define SW_SOC_INCORRECT_TYPE		41
+#define SW_CANNOT_OPEN_LOGFILE		42
 #define SW_SOC_AMBIGUOUS_TYPE		49
 #define SW_ANALYSIS_BEGINS 		52
 #define SW_ANALYSIS_ENDS 		53
+#define SW_EXREQUISITE_EXCLUDE		56
 #define SW_CHECK_SCRIPT_EXCLUDE 	57
 #define SW_CONFIGURE_EXCLUDE 		58
+#define SW_SELECTION_IS_CORRUPT		59
 #define SW_SOURCE_ACCESS_ERROR 		60
+#define SW_SELECTION_NOT_FOUND		62
+#define SW_SELECTION_NOT_FOUND_RELATED	63
+#define SW_SELECTION_NOT_FOUND_AMBIG	64
+#define SW_FILESYSTEMS_NOT_MOUNTED	65
+#define SW_FILESYSTEMS_MORE_MOUNTED	66
 #define SW_HIGHER_REVISION_INSTALLED 	67
+#define SW_NEW_MULTIPLE_VERSION		68
+#define SW_EXISTING_MULTIPLE_VERSION	69
 #define SW_DEPENDENCY_NOT_MET		70
 #define SW_NOT_COMPATIBLE		71
 #define SW_CHECK_SCRIPT_WARNING		72
 #define SW_CHECK_SCRIPT_ERROR 		73
 #define SW_DSA_OVER_LIMIT		75
 #define SW_DSA_FAILED_TO_RUN		76
+#define SW_SAME_REVISION_INSTALLED	77
+#define SW_ALREADY_CONFIGURED		78
 #define SW_SKIPPED_GLOBAL_ERROR 	80
 #define SW_FILE_WARNING			84
 #define SW_FILE_ERROR			85
@@ -56,6 +72,15 @@
 #define SW_SOURCE_ACCESS_BEGINS 	260 /* Not Posix */
 #define SW_SOURCE_ACCESS_ENDS 		261 /* Not Posix */
 #define SW_CONTROL_SCRIPT_ENDS		262 /* Not Posix */
+#define SW_SOC_LOCK_CREATED		263 /* Not Posix */
+#define SW_SOC_LOCK_REMOVED		264 /* Not Posix */
+#define SW_SELECTION_EXECUTION_BEGINS	265 /* Not Posix */
+#define SW_SELECTION_EXECUTION_ENDS	266 /* Not Posix */
+#define SW_ISC_INTEGRITY_CONFIRMED 267 /* Not Posix */
+#define SW_ISC_INTEGRITY_NOT_CONFIRMED 268 /* Not Posix */
+#define SW_SPECIAL_MODE_BEGINS		269 /* Not Posix */
+#define SW_SOC_INTEGRITY_CONFIRMED 	270 /* Not Posix */
+#define SW_SOC_INTEGRITY_NOT_CONFIRMED	271 /* Not Posix */
 
 #define SWI_PRODUCT_SCRIPT_ENDS		280 /* Not Posix */
 #define SWI_FILESET_SCRIPT_ENDS		281 /* Not Posix */
@@ -76,6 +101,8 @@
 #define SWI_ATTRIBUTE			315 /* Not Posix */
 #define SWI_GROUP_BEGINS		316 /* Not Posix */
 #define SWI_GROUP_ENDS			317 /* Not Posix */
+#define SWI_TASK_CTS			318 /* Not Posix  ClearToSend */
+#define SWI_MAIN_SCRIPT_ENDS		319 /* Not Posix */
 
 #define SW_SUCCESS	0
 #define SW_NOTE 	0
@@ -109,4 +136,6 @@ char * swevent_shell_echo(int fdredir, int verbose_level, char * target, int val
 ssize_t swevent_write_rpsh_event(int fd, char * p, int len);
 int swevent_parse_message(char * line, char ** attribute, char ** value);
 struct swEvents * swevent_get_events_array(void);
+char * swevent_code(int value);
+void swevent_set_verbose(int v);
 #endif
