@@ -916,27 +916,36 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 			did_gname = 1;
 			(file_hdr->usage_maskM) |= TARU_UM_GROUP;
 		} else if (strcmp(keyword, "mtime") == 0) {
+			E_DEBUG("mtime");
 			file_hdr->c_mtime = strtoul(value, (char**)NULL, 10);
 			did_mtime = 1;
 			(file_hdr->usage_maskM) |= TARU_UM_MTIME;
-		} else if (strcmp(keyword, "major") == 0) {
+		} else if (strcmp(keyword, SW_A_major) == 0) {
+			E_DEBUG(SW_A_major);
 			file_hdr->c_rdev_maj = swlib_atoi(value, NULL);	
 			did_major = 1;
-		} else if (strcmp(keyword, "minor") == 0) {
+		} else if (strcmp(keyword, SW_A_minor) == 0) {
+			E_DEBUG(SW_A_minor);
 			file_hdr->c_rdev_min = swlib_atoi(value, NULL);	
 			did_minor = 1;
 		} else if (strcmp(keyword, "md5sum") == 0) {
+			E_DEBUG("md5sum");
 			if (file_hdr->digsM) {
+				E_DEBUG("md5sum: DIGS_ENABLE_ON");
 				swlib_strncpy(file_hdr->digsM->md5, value, sizeof(file_hdr->digsM->md5));
 				file_hdr->digsM->do_md5 = DIGS_ENABLE_ON;
 			}
 		} else if (strcmp(keyword, "sha1sum") == 0) {
+			E_DEBUG("sha1sum");
 			if (file_hdr->digsM) {
+				E_DEBUG("sha1sum: DIGS_ENABLE_ON");
 				swlib_strncpy(file_hdr->digsM->sha1, value, sizeof(file_hdr->digsM->sha1));
 				file_hdr->digsM->do_sha1 = DIGS_ENABLE_ON;
 			}
 		} else if (strcmp(keyword, "sha512sum") == 0) {
+			E_DEBUG("sha512sum");
 			if (file_hdr->digsM) {
+				E_DEBUG("sha512sum: DIGS_ENABLE_ON");
 				swlib_strncpy(file_hdr->digsM->sha512, value, sizeof(file_hdr->digsM->sha512));
 				file_hdr->digsM->do_sha512 = DIGS_ENABLE_ON;
 			}
