@@ -6,7 +6,7 @@
  COPYING TERMS AND CONDITIONS:
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,7 @@
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef SWHEADER_122998_H
 #define SWHEADER_122998_H
@@ -36,6 +36,11 @@
 #define SWHEADER_GET_NEXT	0
 #define SWHEADER_PEEK_NEXT	1
 
+typedef struct {
+  int  * save_current_offset_pM; 
+  int    save_current_offsetM; 
+  int    save_current_offset_vM; 
+} SWHEADER_STATE;
 
 typedef struct {              /* swheader object */
   char * image_head_;         /* pointer to the first line of metadata, i.e. offset zero */
@@ -43,10 +48,7 @@ typedef struct {              /* swheader object */
   void * image_object_stack_[SWHEADER_IMAGE_STACK_LEN + 1];
   int  * current_offset_p_;   /* current offset pointer */              
   int    current_offset_;     /* current offset */              
-  int  * save_current_offset_p_; 
-  int    save_current_offset_; 
-  int    save_current_offset_v_; 
-  /* int    length_; */             /* length of metadata including NULL at last byte */
+  SWHEADER_STATE saved_;
   char * (*f_goto_next_)(void * cpp_object, int * current_offset, int peek_only);
                               /* `f_goto_next' provides virtualness over the
 			         iterator method, for C users `cpp_object' is NULL.
@@ -59,8 +61,8 @@ typedef struct {              /* swheader object */
 
 SWHEADER *swheader_open                 (char * (*f)(void *cpp_function, int * object, int peek_only), void * image_object);
 void      swheader_close                (SWHEADER * swheader);
-void	  swheader_store_state(SWHEADER *);
-void	  swheader_restore_state(SWHEADER *);
+void	  swheader_store_state(SWHEADER *, SWHEADER_STATE*);
+void	  swheader_restore_state(SWHEADER *, SWHEADER_STATE*);
 char *	  swheader_f_goto_next		(SWHEADER * swheader);
 void      swheader_set_current_offset   (SWHEADER * swheader, int offset);
 void      swheader_set_current_offset_p (SWHEADER * swheader, int *offset_ptr);
@@ -70,8 +72,6 @@ void      swheader_set_image_head	(SWHEADER * swheader, void * image);
 int       swheader_set_image_object	(SWHEADER * swheader, void * image, int stack_index);
 void      swheader_set_image_object_active(SWHEADER * swheader, int stack_index);
 void *    swheader_get_iter_function 	(SWHEADER * swheader);
-void      swheader_set_image_length     (SWHEADER * swheader, int len);
-int       swheader_get_image_length     (SWHEADER * swheader);
 char *    swheader_get_image_head       (SWHEADER * swheader);
 char **   swheader_get_attribute_by_tag (SWHEADER * swheader, char *object_keyword, char *idtag, char *attribute_keyword);
 char *    swheader_get_object_by_tag    (SWHEADER * swheader, char *object_keyword, char *idtag);
