@@ -18,8 +18,9 @@
 #define SWSSH_SH_SHELL_COMMAND        "/bin/sh -s"
 #define SWSSH_BASH_SHELL_COMMAND      "/bin/bash -s"
 #define SWSSH_KSH_SHELL_COMMAND      "/bin/ksh -s"
-#define SWSSH_ASH_SHELL_COMMAND      "/bin/ash -s"
+#define SWSSH_ASH_SHELL_COMMAND      "/bin/ash -s"   /* not supported */
 #define SWSSH_DASH_SHELL_COMMAND      "/bin/dash -s"
+#define SWSSH_DETECT_POISON_DEFAULT   "exit 1"     /* poison default when auto-detect is on */
 
 /* NOT USED #define SWSSH_SSH_BIN "/usr/bin/ssh" */
 #define SWC_KILL_PID_MARK "_"
@@ -35,5 +36,6 @@ int swssh_protect_shell_metacharacters(STROB * command, int nhops, char * taints
 void swssh_reset_module(void);
 char * swssh_landing_command(char * shellname, int opt_no_getconf);
 void swssh_deactivate_sanity_check(void);
+int swssh_determine_target_path(char * target, char ** path);
 
 #endif
