@@ -6,7 +6,7 @@
    COPYING TERMS AND CONDITIONS:
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,7 @@
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef swutillib_2006_h
 #define swutillib_2006_h
@@ -65,19 +65,23 @@ typedef struct {
 	struct sw_logspec * swu_logspecM;
 	int swu_verboseM;
 	int swu_fail_loudlyM;
-} SWUTIL;
+} SWLOG;
 	
-SWUTIL * swutil_open(void);
-void swutil_close(SWUTIL*);
-void swutil_set_stderr_fd(SWUTIL*, int fd);
+SWLOG * swutil_open(void);
+void swutil_close(SWLOG*);
+void swutil_set_stderr_fd(SWLOG*, int fd);
 
-XFORMAT * swutil_setup_xformat(SWUTIL * swutil, XFORMAT * xformat, int source_fd0, char * source_path,
+XFORMAT * swutil_setup_xformat(SWLOG * swutil, XFORMAT * xformat, int source_fd0, char * source_path,
 		struct extendedOptions * opta, int is_seekable, int g_verboseG, struct sw_logspec * g_logspec,
 		int uinfile_open_flags);
 
 int swutil_doif_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd, char * format, ...);
 int swutil_do_log_is_true(struct sw_logspec * logspec, int verbose_level, int write_at_level);
-int swutil_doif_writef2(SWUTIL * swutil, int write_at_level, char * format, ...);
+int swutil_doif_writef2(SWLOG * swutil, int write_at_level, char * format, ...);
 int swutil_writelogline(int logfd, char * sptr);
-
+int doif_i_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd, char * format, va_list * pap);
+int cpp_doif_i_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd,
+		char * cpp_FILE, int cpp_LINE, char * cpp_FUNCTION, char * format, va_list * pap);
+int swutil_cpp_doif_writef(int verbose_level, int write_at_level, struct sw_logspec * logspec, int fd,
+		char * cpp_FILE, int cpp_LINE, char * cpp_FUNCTION, char * format, ...);
 #endif
