@@ -203,12 +203,11 @@ parse_src_pkg_name(char * pkgfilename, STRAR * st)
 	strob_strcpy(tmp, pkgfilename);
 
 	n = strob_str(tmp);
-	s = (
-		strstr(n, ".tgz") ||
-		strstr(n, ".tar") ||
-		strstr(n, ".tbz") ||
-		(char *)(NULL)
-		);
+	s = NULL;
+	if (!s) s = strstr(n, ".tgz");
+	if (!s) s = strstr(n, ".tar");
+	if (!s) s = strstr(n, ".tbz");
+
 	if (!s) {
 		;
 		/* return -1; */
@@ -240,7 +239,6 @@ plain_source_tarball_write_psf_buf(TOPSF * topsf, STROB * psf)
 	STROB * xtmp;
 	STROB * desc;
 	STROB * title;
-	STROB * doinst;
 
 	STRAR * name_fields;
 	XFORMAT * xformat;
@@ -252,7 +250,6 @@ plain_source_tarball_write_psf_buf(TOPSF * topsf, STROB * psf)
 	char * build_num;
 
 	dir_mtime = (time_t)0;
-	doinst = NULL;
 	name_fields = strar_open();
 	xtmp = strob_open(32);
 	tmp = strob_open(32);
@@ -394,11 +391,13 @@ slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 	STROB * title;
 	STROB * slack_desc;
 	STROB * doinst;
+	STROB * vola;
 
 	STRAR * name_fields;
 	XFORMAT * xformat;
 	AHS * ahs;
 	struct stat st;
+	char * sb;
 	char * name;
 	char * version;
 	char * arch;
@@ -411,6 +410,7 @@ slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 	tmp = strob_open(32);
 	desc = strob_open(32);
 	title = strob_open(32);
+	vola = strob_open(32);
 	
 	if (topsf->pkgfilenameM == NULL) {
 		fprintf(stderr, "%s: must specify a slackware package as a regular file arg\n", swlib_utilname_get());
@@ -491,21 +491,36 @@ slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 
 	/* Now audit the ./install/ directory contents */
 
-	while (
-		(name=xformat_get_next_dirent(xformat, &st)) != NULL &&
-		strstr(name, "install/") == name
-	) {
-		E_DEBUG("");
-		if (strcmp(name, "install/doinst.sh") == 0) {
-			topsf_h_write_to_buf(xformat, name, &doinst);
-		} else if (strcmp(name, "install/") == 0) {
-			;
-		} else if (strcmp(name, "install/slack-desc") == 0) {
-			topsf_h_write_to_buf(xformat, name, &slack_desc);
-		} else {
-			topsf_h_write_to_buf(xformat, name, NULL);
-			fprintf(stderr, "%s: unrecognized skackware control file: %s\n", swlib_utilname_get(), name);
+	name = xformat_get_next_dirent(xformat, &st);
+	while (name) {
+		if (
+			strstr(name, "./install/") == name ||
+			strstr(name, "install/") == name
+		) {
+			if (strstr(name, "./install/") == name)
+				name += 2;
+			E_DEBUG2("NAME=%s", name);
+			if (strcmp(name, "install/doinst.sh") == 0) {
+				topsf_h_write_to_buf(xformat, name, &doinst);
+			} else if (strcmp(name, "install/") == 0) {
+				;
+			} else if (strcmp(name, "install/slack-desc") == 0) {
+				topsf_h_write_to_buf(xformat, name, &slack_desc);
+			} else {
+				topsf_h_write_to_buf(xformat, name, NULL);
+				fprintf(stderr, "%s: unrecognized skackware control file: %s\n",
+					swlib_utilname_get(), name);
+			}
+		} else if (
+			(sb=strstr(name, ".new")) != NULL &&  /* volatile file */
+ 			(*(sb+4) == '\0') 
+		) {
+			strob_sprintf(vola, 1, "file\n");
+			strob_sprintf(vola, 1, "source %s\n", name);
+			strob_sprintf(vola, 1, "path /%s\n", name);
+			strob_sprintf(vola, 1, "is_volatile true\n");
 		}
+		name = xformat_get_next_dirent(xformat, &st);
 	}
 
 	if (slack_desc) {
@@ -546,6 +561,7 @@ slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 	/* Recursive spec after the leading ./ */
 
 	strob_sprintf(psf, STROB_DO_APPEND, SW_A_file " *\n");
+	strob_sprintf(psf, STROB_DO_APPEND, "%s\n", strob_str(vola));
 	strob_sprintf(psf, STROB_DO_APPEND, "#" SW_A_exclude " control\n");
 	strob_sprintf(psf, STROB_DO_APPEND, "#" SW_A_exclude " control/*\n");
 	strob_sprintf(psf, STROB_DO_APPEND, SW_A_exclude " PSF\n");
