@@ -148,6 +148,28 @@ shls_write_cat_ar() {
 	return "$?"
 }
 
+shls_write_files_ar() {
+	# Prefix: xxc
+	PAXCMD="dd count=2 if=/dev/zero"
+	shls_missing_which pax 0</dev/null 1>/dev/null 2>/dev/null
+	xxc_ret=$?
+	case "$xxc_ret" in 0) PAXCMD="pax -d -b 512 -w"; ;; esac
+	shls_check_for_gnu_tar 0</dev/null
+	xxc_ret=$?
+	case "$xxc_ret" in 0) PAXCMD="tar cf - -b1 --no-recursion --files-from=-"; ;; esac
+	case "$PAXCMD" in
+		dd*)
+			dd of=/dev/null 2>/dev/null
+			$PAXCMD 2>/dev/null
+			return 126
+			;;
+		*)
+			$PAXCMD
+			;;
+	esac
+	return "$?"
+}
+
 shls_get_verid_list() {
 	# Prefix: xxf
 	find . -type f -name 'INSTALLED' |
