@@ -2,48 +2,47 @@
  */
 
 /* 
-   Copyright (C) 1995,1996,1997,1998,2000,2001,2005  James H. Lowe, Jr.
-   All rights reserved.
+ Copyright (C) 1995,1996,1997,1998,2000,2001,2005  James H. Lowe, Jr.
+ All rights reserved.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 3, or (at your option)
+ any later version.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "strob.h"
 #include "swuser_config.h"
-static STROB * strob_reopen_if(size_t reqd_length, STROB * strb);
-static void * strob_set_up(STROB *strb, int n);
-
+#include "strob.h"
 
 #define o__inline__
 
-/*
-static
-size_t
-my_strlen(char * str)
-{
-	unsigned char * p = (unsigned char*)str;
-	if (str == NULL) return 0;
-	while(*p) {
-		p++;
-	}
-	return (size_t)(p - (unsigned char*)(str)); 
-}
-*/
+#define S_MEM_CACHE 1   /* define to use MEM_CACHE */
+			/* MEM_CACHE defers free() of strob objects until the
+			   program exits, it maintains a list of active and unactive
+			   objects.  It appears to result in *no* performance gains */
+#undef S_MEM_CACHE
 
+static
+int 
+sb_close(STROB * strb)
+{
+	swbis_free(strb->str_);
+	swbis_free(strb);
+	return 0;
+}
+
+static
 STROB *
-strob_open(size_t initial_size)
+sb_open(size_t initial_size)
 {
 	STROB *strb;
 
@@ -60,15 +59,155 @@ strob_open(size_t initial_size)
 	strb->extra_ = STROB_LENGTHINCR;
 	strb->length_ = 0;
 	strb->str_ = (unsigned char*)NULL;
+	strb->in_use_ = 1;
 	strob_reopen(initial_size + 1, strb);
 	return strb;
 }
 
+#ifdef S_MEM_CACHE
+#include "cplob.h"
+
+static CPLOB * blM;
+static int last_indexM;
+
+static
+void
+bl_create(void)
+{
+	blM = cplob_open(100);
+	cplob_add_nta(blM, (char*)(NULL));
+}
+
+static
+void
+bl_add(STROB * s)
+{
+	if (blM == NULL) bl_create();
+	cplob_add_nta(blM, (char*)s);
+}
+
+static
+STROB *
+bl_find_at(int last)
+{
+	STROB * s;
+	int i;
+
+	if (blM == NULL)
+		bl_create();
+	i = last;
+	while((s=(STROB*)cplob_val(blM, i)) != NULL)
+	{
+		if (s->in_use_ == 0) {
+			last_indexM = i;
+			/* fprintf(stderr, "reusing strob at %d\n", i); */
+			break;
+		}
+		i++;
+	}
+	return s;
+}
+
+static
+STROB *
+bl_find(void)
+{
+	STROB * s;
+	s = bl_find_at(last_indexM);
+	if (s == NULL)
+		s = bl_find_at(0);
+	return s;
+}
+
+static
+STROB *
+bl_open(size_t initial_size)
+{
+	STROB * s;
+
+	s = bl_find();
+	if (s == NULL) {
+		s = sb_open(initial_size);
+		if (s) bl_add(s);
+	} else {
+		s->in_use_ = 1;
+		strob_reopen(initial_size + 1, s);
+	}
+	return s;
+}
+
+static
+int
+bl_close(STROB * s)
+{
+	s->in_use_ = 0;
+	memset(s->str_, (int)'\0', s->reserve_);
+	return 0;
+}
+
+#endif
+
+/* =============================================================== */
+
+static
+STROB *
+strob_reopen_if(size_t reqd_length, STROB * strb)
+{
+	if ((int)reqd_length > strb->reserve_){
+		return strob_reopen(reqd_length + strb->extra_, strb);
+	}
+	return strb;
+}
+
+static
+void *
+strob_set_up(STROB *strb, int n)
+{
+	if (!strob_reopen_if(n+1, strb))
+		return (char *)(NULL);
+
+	if (n > strb->length_) {
+		strb->length_ = n;
+		strb->str_[n]='\0';
+	}
+	return strb;
+}
+
+int 
+strob_close(STROB * strb)
+{
+#ifdef S_MEM_CACHE
+	return bl_close(strb);
+#else
+	return sb_close(strb);
+#endif
+}
+
+
+STROB *
+strob_open(size_t initial_size)
+{
+#ifdef S_MEM_CACHE
+	return bl_open(initial_size);
+#else
+	return sb_open(initial_size);
+#endif
+}
+
 char *
 strob_release(STROB * strb)
 {
 	char *x = (char*)(strb->str_);
+#ifdef S_MEM_CACHE
+	strb->extra_ = STROB_LENGTHINCR;
+	strb->length_ = 0;
+	strb->str_ = (unsigned char*)NULL;
+	strb->in_use_ = 1;
+	strob_reopen(STROB_INITLENGTH + 1, strb);
+	strob_close(strb);
+#else
 	swbis_free(strb);
+#endif
 	return x;
 }
 
@@ -79,14 +218,6 @@ strob_set_reserve(STROB * strb, int res)
 	strb->extra_ = res;
 }
 
-int 
-strob_close(STROB * strb)
-{
-	swbis_free(strb->str_);
-	swbis_free(strb);
-	return 0;
-}
-
 STROB *
 strob_reopen(size_t new_length, STROB * strb)
 {
@@ -188,9 +319,8 @@ strob_chr_index(STROB * strb, int index, int ch)
 int
 strob_get_char(STROB * strb, int index)
 {
-	if (index < 0) return (int)('\0');
-	if (index >= strb->length_)
-		return (int)('\0');
+	if (index < 0) return -1;
+	if (index >= strb->length_) return -1;
 	return (int) strb->str_[index];
 }
 
@@ -236,18 +366,14 @@ strob_strncat(STROB * strb, char *str, size_t len)
 	char * cret;
 	STROB *strb_ret;
 	int ilen;
-	
-	if (len > strlen(str)) 
-		ilen = strlen(str);
-	else
-		ilen = (int)len;
 
-	strb_ret = strob_reopen_if(strlen((char*)(strb->str_)) + ilen + 1,
-								strb);
-	if (!strb_ret)
+	ilen = (int)len;
+	strb_ret = strob_reopen_if(strlen((char*)(strb->str_)) + ilen + 1, strb);
+	if (!strb_ret) {
 		return (char *)(NULL);
-	strb->length_ = strlen((char*)(strb->str_)) + ilen;
+	}
 	cret = strncat((char*)(strb->str_), str, ilen);
+	strb->length_ = strlen((char*)(strb->str_));
 	(strb->str_)[strb->length_] = '\0';
 	return cret;
 }
@@ -351,7 +477,8 @@ strob_strtok(STROB * buf, char *s, const char * delim)
 	char * m;	
 	char * end;	
 	if (s) {
-		strob_strcpy(buf, s);
+		if (s != (char*)(buf->str_))
+			strob_strcpy(buf, s);
 		buf->tok_ = strob_str(buf);
 	}
 	start = buf->tok_;
@@ -450,6 +577,13 @@ strob_memcpy(STROB *strb, void * ct, size_t n)
 	return memcpy(strb->str_, ct, n);
 }
 
+void
+strob_append_hidden_null(STROB *strb)
+{
+	strob_set_up(strb, strb->length_+1);
+	memcpy(strb->str_+strb->length_, "\0", 1);
+}
+
 void *
 strob_memcpy_at(STROB *strb, void * ct, size_t n, size_t offset)
 {
@@ -526,31 +660,6 @@ strob_catstr(STROB * strb, char *str)
 	return strob_strcat(strb, str);
 }
 
-
-/* ----------------------- private functions ----------------------------*/
-
-static STROB *
-strob_reopen_if(size_t reqd_length, STROB * strb)
-{
-	if ((int)reqd_length > strb->reserve_){
-		return strob_reopen(reqd_length + strb->extra_, strb);
-	}
-	return strb;
-}
-
-static void *
-strob_set_up(STROB *strb, int n)
-{
-	if (!strob_reopen_if(n+1, strb))
-		return (char *)(NULL);
-
-	if (n > strb->length_) {
-		strb->length_ = n;
-		strb->str_[n]='\0';
-	}
-	return strb;
-}
-
 int
 strob_vsprintf(STROB * sb, int do_append, char * format, va_list ap)
 {
@@ -588,7 +697,6 @@ strob_vsprintf(STROB * sb, int do_append, char * format, va_list ap)
 	return ret;
 }
 
-
 int
 strob_sprintf(STROB * sb, int do_append, char * format, ...)
 {
