@@ -311,6 +311,9 @@ swi_package_create(void)
 	s->qualifierM = (char*)NULL;
 	s->is_minimal_layoutM = 0;
 	s->installer_sigM = NULL;
+	s->installed_catalog_ownerM = NULL;
+	s->installed_catalog_groupM = NULL;
+	s->installed_catalog_modeM = (mode_t)(0);
 	return s;
 }
 
