@@ -8,7 +8,7 @@
    COPYING TERMS AND CONDITIONS:
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,8 +16,9 @@
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
+#include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -26,6 +27,7 @@
 #include <limits.h>
 #include "ahs.h"
 #include "swvarfs.h"
+#include "strar.h"
 #include "swlib.h"
 #include "swi_debug.h"
 #include "swi.h"
@@ -38,6 +40,7 @@ static STROB * buf4 = NULL;
 static STROB * buf6 = NULL;
 static STROB * buf8 = NULL;
 static STROB * buf9 = NULL;
+static STROB * bufbase = NULL;
 
 char *
 swi_script_list_dump_string_s(SWI_SCRIPTS * xx, char * prefix)
@@ -65,15 +68,20 @@ char *
 swi_xfile_member_dump_string_s(SWI_FILE_MEMBER * xx, char * prefix)
 {
 	STROB * buf;
+	STROB * tmp = strob_open(10);
 	char * datap;	
 	char * newline;	
 	if (buf1 == (STROB*)NULL) buf1 = strob_open(100);
 	buf = buf1;
 
 	strob_sprintf(buf, 0, "%s%p (SWI_FILE_MEMBER*)\n", prefix,  (void*)xx);
-	strob_sprintf(buf, 1, "%s%p->pathnameM       = [%s]\n", prefix, (void*)xx,  xx->pathnameM);
-	strob_sprintf(buf, 1, "%s%p->is_activeM      = [%d]\n", prefix, (void*)xx,  xx->baseM.is_activeM);
-	strob_sprintf(buf, 1, "%s%p->lenM            = [%d]\n", prefix, (void*)xx,  xx->lenM);
+
+	strob_sprintf(buf, 1, "%s%p->baseM  = [%p]\n", prefix, (void*)xx,  (void*)(&(xx->baseM)));
+	strob_sprintf(tmp, 0, "%s%p->baseM:", prefix, (void*)(&(xx->baseM)));
+	strob_sprintf(buf, 1, "%s", swi_base_dump_string_s(&(xx->baseM), strob_str(tmp)));
+
+	strob_sprintf(buf, 1, "%s%p->pathnameM         = [%s]\n", prefix, (void*)xx,  xx->pathnameM);
+	strob_sprintf(buf, 1, "%s%p->lenM              = [%d]\n", prefix, (void*)xx,  xx->lenM);
 	strob_sprintf(buf, 1, "%s%p->dataM T>>>>>> BEGIN DATA\n", prefix, (void*)xx);
 	datap = xx->dataM;
 	newline = datap;
@@ -86,6 +94,7 @@ swi_xfile_member_dump_string_s(SWI_FILE_MEMBER * xx, char * prefix)
 		datap++;
 	}
 	strob_sprintf(buf, 1, "%s%p->dataM T>>>>>> END DATA\n", prefix, (void*)xx);
+	strob_close(tmp);
 	return strob_str(buf);
 }
 
@@ -117,7 +126,7 @@ swi_xfile_script_dump_string_s(SWI_CONTROL_SCRIPT * xx, char * prefix)
 	buf = buf2;
 
 	strob_sprintf(buf, 0, "%s%p (SWI_CONTROL_SCRIPT*)\n", prefix,  (void*)xx);
-	strob_sprintf(buf, 1, "%s%p->is_activeM  = [%d]\n", prefix, (void*)xx,  xx->baseM.is_activeM);
+	strob_sprintf(buf, 1, "%s%p->baseM.is_activeM  = [%d]\n", prefix, (void*)xx,  xx->baseM.is_activeM);
 	strob_sprintf(buf, 1, "%s%p->tagM        = [%s]\n", prefix, (void*)xx,  xx->baseM.tagM);
 	strob_sprintf(buf, 1, "%s%p->resultM     = [%d]\n", prefix, (void*)xx,  xx->resultM);
 	strob_sprintf(buf, 1, "%s%p->afileM      = [%p]\n", prefix, (void*)xx,  xx->afileM);
@@ -126,6 +135,80 @@ swi_xfile_script_dump_string_s(SWI_CONTROL_SCRIPT * xx, char * prefix)
 	return strob_str(buf);
 }
 
+char * 
+swi_base_dump_string_s(SWI_BASE * xx, char * prefix)
+{
+	int i = 0;
+	STROB * tmp = strob_open(1);
+	STROB * buf;
+	STROB * bufverid;
+	char * tmp_s;
+	int current_offset;
+
+	if (bufbase == (STROB*)(NULL)) bufbase = strob_open(100);
+	buf = bufbase;
+	bufverid = strob_open(32);
+
+
+	strob_sprintf(buf, 0, "%s%p (SWI_BASE*)\n", prefix,  (void*)xx);
+	strob_sprintf(buf, 1, "%s%p->id_startM       = [%d]\n", prefix, (void*)xx,     (int)(xx->id_startM));
+	strob_sprintf(buf, 1, "%s%p->type_idM        = [%d]\n", prefix, (void*)xx,     (int)(xx->type_idM));
+	strob_sprintf(buf, 1, "%s%p->is_activeM      = [%d]\n", prefix, (void*)xx,     xx->is_activeM);
+	strob_sprintf(buf, 1, "%s%p->tagM            = [%s]\n", prefix, (void*)xx,     xx->tagM);
+	strob_sprintf(buf, 1, "%s%p->create_timeM    = [%lu]\n", prefix, (void*)xx,    (unsigned long)(xx->create_timeM));
+	strob_sprintf(buf, 1, "%s%p->mod_timeM       = [%lu]\n", prefix, (void*)xx,    (unsigned long)(xx->mod_timeM));
+	strob_sprintf(buf, 1, "%s%p->header_indexM   = [%d]\n", prefix, (void*)xx,     xx->header_indexM);
+	strob_sprintf(buf, 1, "%s%p->global_headerM  = [%p]\n", prefix, (void*)xx,     (void*)(xx->global_headerM));
+ 	strob_sprintf(buf, 1, "%s%p->swveridM        = [%p]\n", prefix, (void*)xx,     (void*)(xx->swveridM));
+ 	strob_sprintf(buf, 1, "%s%p->%p->swverid_print() = [%s]\n", prefix, (void*)xx, (void*)(xx->swveridM), swverid_print(xx->swveridM, tmp));
+
+	strob_sprintf(tmp, 0, "%s->%p:", prefix, (void*)(xx->swveridM));
+ 	strob_sprintf(buf, 1, "%s%p->swveridM        = [%s]\n",
+				prefix, (void*)xx, swverid_show_object_debug(xx->swveridM, bufverid, strob_str(tmp)));
+	strob_sprintf(buf, 1, "%s%p->verboseM        = [%d]\n", prefix, (void*)xx,     xx->verboseM);
+	strob_sprintf(buf, 1, "%s%p->id_endM         = [%d]\n", prefix, (void*)xx,     (int)(xx->id_endM));
+
+
+	/* Print the object from the INDEX file */
+
+	strob_sprintf(buf, 1, "%s%p->(implied data) T>>>>>> BEGIN INDEX DATA\n", prefix, (void*)xx);
+	if (xx->global_headerM) {
+		char * next_attr;
+		char * obj;
+		int level;
+		int memfd;
+		int len;
+		char * image;
+/* JL fprintf(stderr, "JL [%d]\n", xx->header_indexM); */
+		current_offset = swheader_get_current_offset(xx->global_headerM);
+		swheader_set_current_offset(xx->global_headerM, xx->header_indexM);
+
+		obj = swheader_get_current_line(xx->global_headerM);
+		level = swheaderline_get_level(obj);
+
+		memfd = swlib_open_memfd();
+
+		swheaderline_write_debug(obj, memfd);
+		while((next_attr=swheader_get_next_attribute(xx->global_headerM)))
+			swheaderline_write_debug(next_attr, memfd);
+
+		image = swi_com_get_fd_mem(memfd, &len);
+		strob_strcpy(tmp, image);
+		uxfio_close(memfd);
+
+		strob_sprintf(buf, 1, "%s", strob_str(tmp));
+
+		swheader_set_current_offset(xx->global_headerM, current_offset);
+	} else {
+		strob_sprintf(buf, 1, "%s%p->(implied data)\n", prefix, (void*)xx);
+	}
+	strob_sprintf(buf, 1, "%s%p->(implied data) T>>>>>> END INDEX DATA\n", prefix, (void*)xx);
+
+
+	strob_close(tmp);
+	return strob_str(buf);
+}
+
 char * 
 swi_xfile_dump_string_s(SWI_XFILE * xx, char * prefix)
 {
@@ -134,22 +217,26 @@ swi_xfile_dump_string_s(SWI_XFILE * xx, char * prefix)
 	char * tmp_s;
 	SWI_FILE_MEMBER * afile;
 	STROB * buf;
+	int current_offset;
 
 	if (buf0 == (STROB*)(NULL)) buf0 = strob_open(100);
 	buf = buf0;
 
 	strob_sprintf(buf, 0, "%s%p (SWI_XFILE*)\n", prefix,  (void*)xx);
-	strob_sprintf(buf, 1, "%s%p->is_selectedM    = [%d]\n", prefix, (void*)xx,  xx->is_selectedM);
-	strob_sprintf(buf, 1, "%s%p->typeM           = [%d]\n", prefix, (void*)xx,  xx->typeM);
-	strob_sprintf(buf, 1, "%s%p->package_pathM   = [%s]\n", prefix, (void*)xx,  xx->package_pathM);
-	strob_sprintf(buf, 1, "%s%p->control_dirM    = [%s]\n", prefix, (void*)xx,  xx->control_dirM);
-	strob_sprintf(buf, 1, "%s%p->baseM.tagM            = [%s]\n", prefix, (void*)xx,  xx->baseM.tagM);
-	strob_sprintf(buf, 1, "%s%p->swi_scM         = [%p]\n", prefix, (void*)xx,  xx->swi_scM);
-	strob_sprintf(buf, 1, "%s%p->headerM         = [%p]\n", prefix, (void*)xx,  xx->info_headerM);
+
+	strob_sprintf(buf, 1, "%s%p->baseM  = [%p]\n", prefix, (void*)xx,  (void*)(&(xx->baseM)));
+	strob_sprintf(tmp, 0, "%s%p->baseM:", prefix, (void*)(&(xx->baseM)));
+	strob_sprintf(buf, 1, "%s", swi_base_dump_string_s(&(xx->baseM), strob_str(tmp)));
+
+	strob_sprintf(buf, 1, "%s%p->is_selectedM    = [%d]\n", prefix, (void*)xx,     xx->is_selectedM);
+	strob_sprintf(buf, 1, "%s%p->typeM           = [%d]\n", prefix, (void*)xx,     xx->typeM);
+	strob_sprintf(buf, 1, "%s%p->package_pathM   = [%s]\n", prefix, (void*)xx,     xx->package_pathM);
+	strob_sprintf(buf, 1, "%s%p->control_dirM    = [%s]\n", prefix, (void*)xx,     xx->control_dirM);
+	strob_sprintf(buf, 1, "%s%p->swi_scM         = [%p]\n", prefix, (void*)xx,     xx->swi_scM);
+	strob_sprintf(buf, 1, "%s%p->headerM         = [%p]\n", prefix, (void*)xx,     xx->info_headerM);
 	strob_sprintf(buf, 1, "%s%p->INFO_header_indexM   = [%d]\n", prefix, (void*)xx,  xx->INFO_header_indexM);
-	strob_sprintf(buf, 1, "%s%p->INDEX_header_indexM   = [%d]\n", prefix, (void*)xx,  xx->baseM.header_indexM);
-	strob_sprintf(buf, 1, "%s%p->archive_filesM  = [%p]\n", prefix, (void*)xx,  xx->archive_filesM);
-	strob_sprintf(buf, 1, "%s%p->swdef_fdM       = [%d]\n",  prefix, (void*)xx,  xx->swdef_fdM);
+	strob_sprintf(buf, 1, "%s%p->archive_filesM  = [%p]\n", prefix, (void*)xx,       xx->archive_filesM);
+	strob_sprintf(buf, 1, "%s%p->swdef_fdM       = [%d]\n",  prefix, (void*)xx,      xx->swdef_fdM);
 	strob_sprintf(buf, 1, "%s%p->did_parse_def_fileM = [%d]\n",  prefix, (void*)xx,  xx->did_parse_def_fileM);
 
 	i = 0;
@@ -183,6 +270,7 @@ swi_product_dump_string_s(SWI_PRODUCT * xx, char * prefix)
 	*/
 	int i = 0;
 	STROB * buf;
+	STROB * tmp = strob_open(1);
 	SWI_XFILE * xfile;
 	char * tmp_s;
 	
@@ -190,9 +278,13 @@ swi_product_dump_string_s(SWI_PRODUCT * xx, char * prefix)
 	buf = buf6;
 
 	strob_sprintf(buf, 0, "%s%p (SWI_PRODUCT*)\n", prefix,  (void*)xx);
+
+	strob_sprintf(buf, 1, "%s%p->baseM  = [%p]\n", prefix, (void*)xx,  (void*)(&(xx->baseM)));
+	strob_sprintf(tmp, 0, "%s%p->baseM:", prefix, (void*)(&(xx->baseM)));
+	strob_sprintf(buf, 1, "%s", swi_base_dump_string_s(&(xx->baseM), strob_str(tmp)));
+
 	strob_sprintf(buf, 1, "%s%p->package_pathM   = [%s]\n", prefix, (void*)xx,  xx->package_pathM);
 	strob_sprintf(buf, 1, "%s%p->control_dirM    = [%s]\n", prefix, (void*)xx,  xx->control_dirM);
-	strob_sprintf(buf, 1, "%s%p->baseM.tagM            = [%s]\n", prefix, (void*)xx,  xx->baseM.tagM);
 	strob_sprintf(buf, 1, "%s%p->pfilesM         = [%p]\n", prefix, (void*)xx,  (void*)(xx->pfilesM));
 	
 	strob_sprintf(buf, 1, "%s%p->pfilesM         = [%p] (BEGIN PFILES)\n",
@@ -231,6 +323,7 @@ swi_product_dump_string_s(SWI_PRODUCT * xx, char * prefix)
 					prefix, (void*)xx, i, (void*)(xx->swi_coM[i]), i);
 		i++;
 	}
+	strob_close(tmp);
 	return strob_str(buf);
 }
 
@@ -238,6 +331,7 @@ char *
 swi_package_dump_string_s(SWI_PACKAGE * xx, char * prefix)
 {
 	STROB * buf;
+	STROB * tmp = strob_open(1);
 	SWI_PRODUCT * prod;
 	int i;
 	STROB * tmpprefix = strob_open(10);
@@ -247,6 +341,11 @@ swi_package_dump_string_s(SWI_PACKAGE * xx, char * prefix)
 	buf = buf8;
 
 	strob_sprintf(buf, 0, "%s%p (SWI_PACKAGE*)\n", prefix,  (void*)xx);
+
+	strob_sprintf(buf, 1, "%s%p->baseM  = [%p]\n", prefix, (void*)xx,  (void*)(&(xx->baseM)));
+	strob_sprintf(tmp, 0, "%s%p->baseM:", prefix, (void*)(&(xx->baseM)));
+	strob_sprintf(buf, 1, "%s", swi_base_dump_string_s(&(xx->baseM), strob_str(tmp)));
+
 	strob_sprintf(buf, 1, "%s%p->swi_scM         = [%p]\n", prefix, (void*)xx,  xx->swi_scM);
 	strob_sprintf(buf, 1, "%s%p->exlistM             = [%p]\n", prefix, (void*)xx,  xx->exlistM);
 	strob_sprintf(buf, 1, "%s%p->dfilesM             = [%p]\n", prefix, (void*)xx,  xx->dfilesM);
@@ -286,6 +385,7 @@ swi_package_dump_string_s(SWI_PACKAGE * xx, char * prefix)
 				 prefix, (void*)xx, i, (void*)(xx->swi_coM[i]), i);
 		i++;
 	}
+	strob_close(tmp);
 	strob_close(tmpprefix);
 	return strob_str(buf);
 }
