@@ -303,6 +303,7 @@ taru_write_preview_line(TARU * taru, struct new_cpio_header *file_hdr)
 	char * filename;
 	STROB * buffer;
 
+	flag = 0;
 	if (
 		taru->preview_fdM < 0 ||
 		taru->preview_levelM == TARU_PV_0
@@ -328,7 +329,7 @@ taru_write_preview_line(TARU * taru, struct new_cpio_header *file_hdr)
 	} else if (level >= TARU_PV_1) {
 		/* strob_sprintf(buffer, 0, "%s\n", filename); */
 		strob_strcpy(buffer, "");
-		ls_list_safe_print_to_strob(filename, buffer);
+		ls_list_safe_print_to_strob(filename, buffer, 0);
 		strob_strcat(buffer, "\n");
 	} else {
 		strob_strcpy(buffer, "");
