@@ -404,7 +404,7 @@ int taru_get_preview_level(TARU * taru);
 int taru_set_tar_header_policy(TARU * taru, char * user_format, int * p_arf_format);
 
 FILE_DIGS * taru_digs_create(void);
-void taru_digs_init(FILE_DIGS *, int);
+void taru_digs_init(FILE_DIGS *, int, int);
 void taru_digs_print(FILE_DIGS * digs, STROB * );
 
 #endif
