@@ -1313,7 +1313,7 @@ xformat_copy_pass_md5(XFORMAT * xux, int dst_fd, int src_fd, char * md5buf)
 		}
 	} else {
 		digs = taru_digs_create();
-		taru_digs_init(digs, DIGS_ENABLE_OFF);
+		taru_digs_init(digs, DIGS_ENABLE_OFF, 0);
 		digs->do_md5 = DIGS_ENABLE_ON;
 		old_digs = file_hdr0->digsM;
 		file_hdr0->digsM = digs;
