@@ -16,7 +16,7 @@ int
 main (int argc, char ** argv )
 {
 	FILE_DIGS digs;
-	taru_digs_init(&digs, DIGS_ENABLE_ON);
+	taru_digs_init(&digs, DIGS_ENABLE_ON, 0);
 
 	digs.do_md5 = DIGS_ENABLE_ON;
 	digs.do_sha1 = DIGS_ENABLE_ON;
