@@ -1,7 +1,5 @@
-#ifdef DOTO_ID
-static char testswdefinitionwrite_cxx[] =
-"$Id$";
-#endif
+/* testheader.cxx
+*/
 
 #include "swuser_config.h"
 #include <stdio.h>
